/*
 * Copyright (C) 2010-2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/EnumTraits.h>

namespace IPC {

enum class ReceiverName : uint8_t {
    GPUConnectionToWebProcess = 1
    , GPUProcess = 2
    , RemoteRenderingBackendProxy = 3
    , RemoteAudioDestinationManager = 4
    , RemoteAudioSessionProxy = 5
    , RemoteCDMFactoryProxy = 6
    , RemoteCDMInstanceProxy = 7
    , RemoteCDMInstanceSessionProxy = 8
    , RemoteCDMProxy = 9
    , RemoteLegacyCDMFactoryProxy = 10
    , RemoteLegacyCDMProxy = 11
    , RemoteLegacyCDMSessionProxy = 12
    , RemoteMediaPlayerManagerProxy = 13
    , RemoteMediaPlayerProxy = 14
    , RemoteMediaResourceManager = 15
    , LibWebRTCCodecsProxy = 16
    , RemoteAudioMediaStreamTrackRenderer = 17
    , RemoteAudioMediaStreamTrackRendererManager = 18
    , RemoteMediaRecorder = 19
    , RemoteMediaRecorderManager = 20
    , RemoteSampleBufferDisplayLayer = 21
    , RemoteSampleBufferDisplayLayerManager = 22
    , WebCookieManager = 23
    , WebIDBServer = 24
    , NetworkConnectionToWebProcess = 25
    , NetworkContentRuleListManager = 26
    , NetworkProcess = 27
    , NetworkResourceLoader = 28
    , NetworkSocketChannel = 29
    , NetworkSocketStream = 30
    , ServiceWorkerFetchTask = 31
    , WebSWServerConnection = 32
    , WebSWServerToContextConnection = 33
    , StorageManagerSet = 34
    , CacheStorageEngineConnection = 35
    , NetworkMDNSRegister = 36
    , NetworkRTCMonitor = 37
    , NetworkRTCProvider = 38
    , PluginControllerProxy = 39
    , PluginProcess = 40
    , WebProcessConnection = 41
    , AuxiliaryProcess = 42
    , WebConnection = 43
    , AuthenticationManager = 44
    , NPObjectMessageReceiver = 45
    , DrawingAreaProxy = 46
    , VisitedLinkStore = 47
    , WebCookieManagerProxy = 48
    , WebFullScreenManagerProxy = 49
    , WebGeolocationManagerProxy = 50
    , WebPageProxy = 51
    , WebPasteboardProxy = 52
    , WebProcessPool = 53
    , WebProcessProxy = 54
    , WebAutomationSession = 55
    , DownloadProxy = 56
    , GPUProcessProxy = 57
    , RemoteWebInspectorProxy = 58
    , WebInspectorProxy = 59
    , NetworkProcessProxy = 60
    , PluginProcessProxy = 61
    , WebUserContentControllerProxy = 62
    , WebProcess = 63
    , WebAutomationSessionProxy = 64
    , WebIDBConnectionToServer = 65
    , WebFullScreenManager = 66
    , GPUProcessConnection = 67
    , RemoteRenderingBackend = 68
    , MediaPlayerPrivateRemote = 69
    , RemoteAudioDestinationProxy = 70
    , RemoteAudioSession = 71
    , RemoteCDMInstanceSession = 72
    , RemoteLegacyCDMSession = 73
    , RemoteMediaPlayerManager = 74
    , LibWebRTCCodecs = 75
    , SampleBufferDisplayLayer = 76
    , WebGeolocationManager = 77
    , RemoteWebInspectorUI = 78
    , WebInspector = 79
    , WebInspectorInterruptDispatcher = 80
    , WebInspectorUI = 81
    , LibWebRTCNetwork = 82
    , WebMDNSRegister = 83
    , WebRTCMonitor = 84
    , WebRTCResolver = 85
    , NetworkProcessConnection = 86
    , WebResourceLoader = 87
    , WebSocketChannel = 88
    , WebSocketStream = 89
    , WebNotificationManager = 90
    , PluginProcessConnection = 91
    , PluginProcessConnectionManager = 92
    , PluginProxy = 93
    , WebSWClientConnection = 94
    , WebSWContextManagerConnection = 95
    , WebUserContentController = 96
    , DrawingArea = 97
    , EventDispatcher = 98
    , VisitedLinkTableController = 99
    , WebPage = 100
    , StorageAreaMap = 101
    , ViewGestureController = 102
    , ViewGestureGeometryCollector = 103
    , IPC = 104
    , AsyncReply = 105
    , Invalid = 106
};

enum class MessageName : uint16_t {
    AuthenticationManager_CompleteAuthenticationChallenge
    , AuxiliaryProcess_DidReceiveMemoryPressureEvent
    , AuxiliaryProcess_SetProcessSuppressionEnabled
    , AuxiliaryProcess_ShutDown
    , CacheStorageEngineConnection_Caches
    , CacheStorageEngineConnection_CachesReply
    , CacheStorageEngineConnection_ClearMemoryRepresentation
    , CacheStorageEngineConnection_ClearMemoryRepresentationReply
    , CacheStorageEngineConnection_DeleteMatchingRecords
    , CacheStorageEngineConnection_DeleteMatchingRecordsReply
    , CacheStorageEngineConnection_Dereference
    , CacheStorageEngineConnection_EngineRepresentation
    , CacheStorageEngineConnection_EngineRepresentationReply
    , CacheStorageEngineConnection_Open
    , CacheStorageEngineConnection_OpenReply
    , CacheStorageEngineConnection_PutRecords
    , CacheStorageEngineConnection_PutRecordsReply
    , CacheStorageEngineConnection_Reference
    , CacheStorageEngineConnection_Remove
    , CacheStorageEngineConnection_RemoveReply
    , CacheStorageEngineConnection_RetrieveRecords
    , CacheStorageEngineConnection_RetrieveRecordsReply
    , DownloadProxy_DecideDestinationWithSuggestedFilenameAsync
    , DownloadProxy_DidCancel
    , DownloadProxy_DidCreateDestination
    , DownloadProxy_DidFail
    , DownloadProxy_DidFinish
    , DownloadProxy_DidReceiveAuthenticationChallenge
    , DownloadProxy_DidReceiveData
    , DownloadProxy_DidReceiveResponse
    , DownloadProxy_DidStart
    , DownloadProxy_WillSendRequest
    , DrawingAreaProxy_DidFirstLayerFlush
    , DrawingAreaProxy_DidUpdateBackingStoreState
    , DrawingAreaProxy_DidUpdateGeometry
    , DrawingAreaProxy_DispatchPresentationCallbacksAfterFlushingLayers
    , DrawingAreaProxy_EnterAcceleratedCompositingMode
    , DrawingAreaProxy_ExitAcceleratedCompositingMode
    , DrawingAreaProxy_Update
    , DrawingAreaProxy_UpdateAcceleratedCompositingMode
    , DrawingArea_AcceleratedAnimationDidEnd
    , DrawingArea_AcceleratedAnimationDidStart
    , DrawingArea_AddTransactionCallbackID
    , DrawingArea_AdjustTransientZoom
    , DrawingArea_CommitTransientZoom
    , DrawingArea_DidUpdate
    , DrawingArea_SetColorSpace
    , DrawingArea_SetDeviceScaleFactor
    , DrawingArea_SetViewExposedRect
    , DrawingArea_UpdateBackingStoreState
    , DrawingArea_UpdateGeometry
    , EventDispatcher_DisplayWasRefreshed
    , EventDispatcher_GestureEvent
    , EventDispatcher_TouchEvent
    , EventDispatcher_WheelEvent
    , GPUConnectionToWebProcess_ClearNowPlayingInfo
    , GPUConnectionToWebProcess_CreateRenderingBackend
    , GPUConnectionToWebProcess_EnsureAudioSession
    , GPUConnectionToWebProcess_EnsureMediaSessionHelper
    , GPUConnectionToWebProcess_ReleaseRenderingBackend
    , GPUConnectionToWebProcess_SetNowPlayingInfo
    , GPUProcessConnection_DidReceiveRemoteCommand
    , GPUProcessProxy_DidCreateContextForVisibilityPropagation
    , GPUProcess_AddSession
    , GPUProcess_CreateGPUConnectionToWebProcess
    , GPUProcess_CreateGPUConnectionToWebProcessReply
    , GPUProcess_InitializeGPUProcess
    , GPUProcess_ProcessDidTransitionToBackground
    , GPUProcess_ProcessDidTransitionToForeground
    , GPUProcess_RemoveSession
    , GPUProcess_SetMockCaptureDevicesEnabled
    , GPUProcess_SetOrientationForMediaCapture
    , GPUProcess_UpdateCaptureAccess
    , GPUProcess_UpdateCaptureAccessReply
    , LibWebRTCCodecsProxy_CreateEncoder
    , LibWebRTCCodecsProxy_CreateH264Decoder
    , LibWebRTCCodecsProxy_CreateH265Decoder
    , LibWebRTCCodecsProxy_DecodeFrame
    , LibWebRTCCodecsProxy_EncodeFrame
    , LibWebRTCCodecsProxy_InitializeEncoder
    , LibWebRTCCodecsProxy_ReleaseDecoder
    , LibWebRTCCodecsProxy_ReleaseEncoder
    , LibWebRTCCodecsProxy_SetEncodeRates
    , LibWebRTCCodecs_CompletedDecoding
    , LibWebRTCCodecs_CompletedEncoding
    , LibWebRTCCodecs_FailedDecoding
    , LibWebRTCNetwork_SignalAddressReady
    , LibWebRTCNetwork_SignalClose
    , LibWebRTCNetwork_SignalConnect
    , LibWebRTCNetwork_SignalNewConnection
    , LibWebRTCNetwork_SignalReadPacket
    , LibWebRTCNetwork_SignalSentPacket
    , MediaPlayerPrivateRemote_ActiveSourceBuffersChanged
    , MediaPlayerPrivateRemote_AddDataCue
    , MediaPlayerPrivateRemote_AddDataCueWithType
    , MediaPlayerPrivateRemote_AddGenericCue
    , MediaPlayerPrivateRemote_AddRemoteAudioTrack
    , MediaPlayerPrivateRemote_AddRemoteTextTrack
    , MediaPlayerPrivateRemote_AddRemoteVideoTrack
    , MediaPlayerPrivateRemote_CharacteristicChanged
    , MediaPlayerPrivateRemote_CurrentPlaybackTargetIsWirelessChanged
    , MediaPlayerPrivateRemote_DurationChanged
    , MediaPlayerPrivateRemote_EngineFailedToLoad
    , MediaPlayerPrivateRemote_EngineUpdated
    , MediaPlayerPrivateRemote_FirstVideoFrameAvailable
    , MediaPlayerPrivateRemote_InitializationDataEncountered
    , MediaPlayerPrivateRemote_MediaPlayerKeyNeeded
    , MediaPlayerPrivateRemote_MuteChanged
    , MediaPlayerPrivateRemote_NetworkStateChanged
    , MediaPlayerPrivateRemote_ParseWebVTTCueData
    , MediaPlayerPrivateRemote_ParseWebVTTCueDataStruct
    , MediaPlayerPrivateRemote_ParseWebVTTFileHeader
    , MediaPlayerPrivateRemote_PlaybackStateChanged
    , MediaPlayerPrivateRemote_RateChanged
    , MediaPlayerPrivateRemote_ReadyStateChanged
    , MediaPlayerPrivateRemote_RemoteAudioTrackConfigurationChanged
    , MediaPlayerPrivateRemote_RemoteTextTrackConfigurationChanged
    , MediaPlayerPrivateRemote_RemoteVideoTrackConfigurationChanged
    , MediaPlayerPrivateRemote_RemoveDataCue
    , MediaPlayerPrivateRemote_RemoveGenericCue
    , MediaPlayerPrivateRemote_RemoveRemoteAudioTrack
    , MediaPlayerPrivateRemote_RemoveRemoteTextTrack
    , MediaPlayerPrivateRemote_RemoveRemoteVideoTrack
    , MediaPlayerPrivateRemote_RemoveResource
    , MediaPlayerPrivateRemote_RequestResource
    , MediaPlayerPrivateRemote_RequestResourceReply
    , MediaPlayerPrivateRemote_ResourceNotSupported
    , MediaPlayerPrivateRemote_SendH2Ping
    , MediaPlayerPrivateRemote_SendH2PingReply
    , MediaPlayerPrivateRemote_SizeChanged
    , MediaPlayerPrivateRemote_TimeChanged
    , MediaPlayerPrivateRemote_UpdateCachedState
    , MediaPlayerPrivateRemote_UpdateDataCue
    , MediaPlayerPrivateRemote_UpdateGenericCue
    , MediaPlayerPrivateRemote_VolumeChanged
    , MediaPlayerPrivateRemote_WaitingForKeyChanged
    , NPObjectMessageReceiver_Construct
    , NPObjectMessageReceiver_Deallocate
    , NPObjectMessageReceiver_Enumerate
    , NPObjectMessageReceiver_GetProperty
    , NPObjectMessageReceiver_HasMethod
    , NPObjectMessageReceiver_HasProperty
    , NPObjectMessageReceiver_Invoke
    , NPObjectMessageReceiver_InvokeDefault
    , NPObjectMessageReceiver_RemoveProperty
    , NPObjectMessageReceiver_SetProperty
    , NetworkConnectionToWebProcess_AddOriginAccessWhitelistEntry
    , NetworkConnectionToWebProcess_BlobSize
    , NetworkConnectionToWebProcess_BrowsingContextRemoved
    , NetworkConnectionToWebProcess_CheckRemotePortForActivity
    , NetworkConnectionToWebProcess_CheckRemotePortForActivityReply
    , NetworkConnectionToWebProcess_ClearPageSpecificDataForResourceLoadStatistics
    , NetworkConnectionToWebProcess_CloseSWContextConnection
    , NetworkConnectionToWebProcess_ConvertMainResourceLoadToDownload
    , NetworkConnectionToWebProcess_CookieRequestHeaderFieldValue
    , NetworkConnectionToWebProcess_CookiesForDOM
    , NetworkConnectionToWebProcess_CreateNewMessagePortChannel
    , NetworkConnectionToWebProcess_CreateSocketChannel
    , NetworkConnectionToWebProcess_CreateSocketStream
    , NetworkConnectionToWebProcess_DeleteCookie
    , NetworkConnectionToWebProcess_DidDeliverMessagePortMessages
    , NetworkConnectionToWebProcess_DomCookiesForHost
    , NetworkConnectionToWebProcess_EntangleLocalPortInThisProcessToRemote
    , NetworkConnectionToWebProcess_EstablishSWContextConnection
    , NetworkConnectionToWebProcess_EstablishSWContextConnectionReply
    , NetworkConnectionToWebProcess_GetNetworkLoadInformationResponse
    , NetworkConnectionToWebProcess_GetNetworkLoadIntermediateInformation
    , NetworkConnectionToWebProcess_GetRawCookies
    , NetworkConnectionToWebProcess_HasStorageAccess
    , NetworkConnectionToWebProcess_HasStorageAccessReply
    , NetworkConnectionToWebProcess_LoadPing
    , NetworkConnectionToWebProcess_LogUserInteraction
    , NetworkConnectionToWebProcess_MessagePortClosed
    , NetworkConnectionToWebProcess_MessagePortDisentangled
    , NetworkConnectionToWebProcess_PageLoadCompleted
    , NetworkConnectionToWebProcess_PerformSynchronousLoad
    , NetworkConnectionToWebProcess_PostMessageToRemote
    , NetworkConnectionToWebProcess_PreconnectTo
    , NetworkConnectionToWebProcess_PrefetchDNS
    , NetworkConnectionToWebProcess_RegisterBlobURL
    , NetworkConnectionToWebProcess_RegisterBlobURLForSlice
    , NetworkConnectionToWebProcess_RegisterBlobURLFromURL
    , NetworkConnectionToWebProcess_RegisterBlobURLOptionallyFileBacked
    , NetworkConnectionToWebProcess_RegisterFileBlobURL
    , NetworkConnectionToWebProcess_RegisterURLSchemesAsCORSEnabled
    , NetworkConnectionToWebProcess_RemoveLoadIdentifier
    , NetworkConnectionToWebProcess_RemoveOriginAccessWhitelistEntry
    , NetworkConnectionToWebProcess_RemoveStorageAccessForFrame
    , NetworkConnectionToWebProcess_RequestStorageAccess
    , NetworkConnectionToWebProcess_RequestStorageAccessReply
    , NetworkConnectionToWebProcess_RequestStorageAccessUnderOpener
    , NetworkConnectionToWebProcess_ResetOriginAccessWhitelists
    , NetworkConnectionToWebProcess_ResourceLoadStatisticsUpdated
    , NetworkConnectionToWebProcess_ScheduleResourceLoad
    , NetworkConnectionToWebProcess_SendH2Ping
    , NetworkConnectionToWebProcess_SendH2PingReply
    , NetworkConnectionToWebProcess_SetCaptureExtraNetworkLoadMetricsEnabled
    , NetworkConnectionToWebProcess_SetCookiesFromDOM
    , NetworkConnectionToWebProcess_SetRawCookie
    , NetworkConnectionToWebProcess_StartDownload
    , NetworkConnectionToWebProcess_TakeAllMessagesForPort
    , NetworkConnectionToWebProcess_TakeAllMessagesForPortReply
    , NetworkConnectionToWebProcess_TakeNetworkLoadInformationMetrics
    , NetworkConnectionToWebProcess_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply
    , NetworkConnectionToWebProcess_UnregisterBlobURL
    , NetworkConnectionToWebProcess_UnsubscribeFromCookieChangeNotifications
    , NetworkConnectionToWebProcess_UpdateQuotaBasedOnSpaceUsageForTesting
    , NetworkConnectionToWebProcess_WriteBlobsToTemporaryFiles
    , NetworkConnectionToWebProcess_WriteBlobsToTemporaryFilesReply
    , NetworkContentRuleListManager_AddContentRuleLists
    , NetworkContentRuleListManager_Remove
    , NetworkContentRuleListManager_RemoveAllContentRuleLists
    , NetworkContentRuleListManager_RemoveContentRuleList
    , NetworkMDNSRegister_RegisterMDNSName
    , NetworkMDNSRegister_UnregisterMDNSNames
    , NetworkProcessConnection_AllCookiesDeleted
    , NetworkProcessConnection_BroadcastConsoleMessage
    , NetworkProcessConnection_CheckProcessLocalPortForActivity
    , NetworkProcessConnection_CheckProcessLocalPortForActivityReply
    , NetworkProcessConnection_CookieAcceptPolicyChanged
    , NetworkProcessConnection_CookiesAdded
    , NetworkProcessConnection_CookiesDeleted
    , NetworkProcessConnection_DidCacheResource
    , NetworkProcessConnection_DidFinishPingLoad
    , NetworkProcessConnection_DidFinishPreconnection
    , NetworkProcessConnection_MessagesAvailableForPort
    , NetworkProcessConnection_SetOnLineState
    , NetworkProcessProxy_ContentExtensionRules
    , NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomains
    , NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomainsReply
    , NetworkProcessProxy_DidCommitCrossSiteLoadWithDataTransferFromPrevalentResource
    , NetworkProcessProxy_DidDeleteWebsiteData
    , NetworkProcessProxy_DidDeleteWebsiteDataForOrigins
    , NetworkProcessProxy_DidFetchWebsiteData
    , NetworkProcessProxy_DidNegotiateModernTLS
    , NetworkProcessProxy_DidReceiveAuthenticationChallenge
    , NetworkProcessProxy_DidSyncAllCookies
    , NetworkProcessProxy_EstablishWorkerContextConnectionToNetworkProcess
    , NetworkProcessProxy_EstablishWorkerContextConnectionToNetworkProcessReply
    , NetworkProcessProxy_GetAppBoundDomains
    , NetworkProcessProxy_GetAppBoundDomainsReply
    , NetworkProcessProxy_LogDiagnosticMessage
    , NetworkProcessProxy_LogDiagnosticMessageWithResult
    , NetworkProcessProxy_LogDiagnosticMessageWithValue
    , NetworkProcessProxy_LogTestingEvent
    , NetworkProcessProxy_NegotiatedLegacyTLS
    , NetworkProcessProxy_NotifyResourceLoadStatisticsProcessed
    , NetworkProcessProxy_NotifyResourceLoadStatisticsTelemetryFinished
    , NetworkProcessProxy_NotifyWebsiteDataDeletionForRegistrableDomainsFinished
    , NetworkProcessProxy_NotifyWebsiteDataScanForRegistrableDomainsFinished
    , NetworkProcessProxy_RegisterServiceWorkerClientProcess
    , NetworkProcessProxy_RequestStorageAccessConfirm
    , NetworkProcessProxy_RequestStorageAccessConfirmReply
    , NetworkProcessProxy_RequestStorageSpace
    , NetworkProcessProxy_RequestStorageSpaceReply
    , NetworkProcessProxy_ResourceLoadDidCompleteWithError
    , NetworkProcessProxy_ResourceLoadDidPerformHTTPRedirection
    , NetworkProcessProxy_ResourceLoadDidReceiveChallenge
    , NetworkProcessProxy_ResourceLoadDidReceiveResponse
    , NetworkProcessProxy_ResourceLoadDidSendRequest
    , NetworkProcessProxy_RetrieveCacheStorageParameters
    , NetworkProcessProxy_SetDomainsWithUserInteraction
    , NetworkProcessProxy_SetIsHoldingLockedFiles
    , NetworkProcessProxy_SetWebProcessHasUploads
    , NetworkProcessProxy_TerminateUnresponsiveServiceWorkerProcesses
    , NetworkProcessProxy_TerminateWebProcess
    , NetworkProcessProxy_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply
    , NetworkProcessProxy_UnregisterServiceWorkerClientProcess
    , NetworkProcessProxy_WorkerContextConnectionNoLongerNeeded
    , NetworkProcess_AddWebsiteDataStore
    , NetworkProcess_AllowSpecificHTTPSCertificateForHost
    , NetworkProcess_ApplicationDidEnterBackground
    , NetworkProcess_ApplicationWillEnterForeground
    , NetworkProcess_CancelDownload
    , NetworkProcess_ClearAdClickAttribution
    , NetworkProcess_ClearAdClickAttributionReply
    , NetworkProcess_ClearAppBoundSession
    , NetworkProcess_ClearAppBoundSessionReply
    , NetworkProcess_ClearBundleIdentifier
    , NetworkProcess_ClearBundleIdentifierReply
    , NetworkProcess_ClearCachedCredentials
    , NetworkProcess_ClearLegacyPrivateBrowsingLocalStorage
    , NetworkProcess_ClearPrevalentResource
    , NetworkProcess_ClearPrevalentResourceReply
    , NetworkProcess_ClearServiceWorkerEntitlementOverride
    , NetworkProcess_ClearServiceWorkerEntitlementOverrideReply
    , NetworkProcess_ClearUserInteraction
    , NetworkProcess_ClearUserInteractionReply
    , NetworkProcess_ContinueDecidePendingDownloadDestination
    , NetworkProcess_ContinueWillSendRequest
    , NetworkProcess_CreateNetworkConnectionToWebProcess
    , NetworkProcess_CreateNetworkConnectionToWebProcessReply
    , NetworkProcess_DeleteCookiesForTesting
    , NetworkProcess_DeleteCookiesForTestingReply
    , NetworkProcess_DeleteWebsiteData
    , NetworkProcess_DeleteWebsiteDataForOrigins
    , NetworkProcess_DestroySession
    , NetworkProcess_DidCommitCrossSiteLoadWithDataTransfer
    , NetworkProcess_DisableServiceWorkerEntitlement
    , NetworkProcess_DomainIDExistsInDatabase
    , NetworkProcess_DomainIDExistsInDatabaseReply
    , NetworkProcess_DownloadRequest
    , NetworkProcess_DumpAdClickAttribution
    , NetworkProcess_DumpAdClickAttributionReply
    , NetworkProcess_DumpResourceLoadStatistics
    , NetworkProcess_DumpResourceLoadStatisticsReply
    , NetworkProcess_FetchWebsiteData
    , NetworkProcess_GetAllStorageAccessEntries
    , NetworkProcess_GetAllStorageAccessEntriesReply
    , NetworkProcess_GetLocalStorageOriginDetails
    , NetworkProcess_GetLocalStorageOriginDetailsReply
    , NetworkProcess_GetResourceLoadStatisticsDataSummary
    , NetworkProcess_GetResourceLoadStatisticsDataSummaryReply
    , NetworkProcess_HadUserInteraction
    , NetworkProcess_HadUserInteractionReply
    , NetworkProcess_HasAppBoundSession
    , NetworkProcess_HasAppBoundSessionReply
    , NetworkProcess_HasIsolatedSession
    , NetworkProcess_HasIsolatedSessionReply
    , NetworkProcess_HasLocalStorage
    , NetworkProcess_HasLocalStorageReply
    , NetworkProcess_InitializeNetworkProcess
    , NetworkProcess_InsertExpiredStatisticForTesting
    , NetworkProcess_InsertExpiredStatisticForTestingReply
    , NetworkProcess_IsGrandfathered
    , NetworkProcess_IsGrandfatheredReply
    , NetworkProcess_IsPrevalentResource
    , NetworkProcess_IsPrevalentResourceReply
    , NetworkProcess_IsRegisteredAsRedirectingTo
    , NetworkProcess_IsRegisteredAsRedirectingToReply
    , NetworkProcess_IsRegisteredAsSubFrameUnder
    , NetworkProcess_IsRegisteredAsSubFrameUnderReply
    , NetworkProcess_IsRegisteredAsSubresourceUnder
    , NetworkProcess_IsRegisteredAsSubresourceUnderReply
    , NetworkProcess_IsRelationshipOnlyInDatabaseOnce
    , NetworkProcess_IsRelationshipOnlyInDatabaseOnceReply
    , NetworkProcess_IsResourceLoadStatisticsEphemeral
    , NetworkProcess_IsResourceLoadStatisticsEphemeralReply
    , NetworkProcess_IsVeryPrevalentResource
    , NetworkProcess_IsVeryPrevalentResourceReply
    , NetworkProcess_LogFrameNavigation
    , NetworkProcess_LogUserInteraction
    , NetworkProcess_LogUserInteractionReply
    , NetworkProcess_MarkAdClickAttributionsAsExpiredForTesting
    , NetworkProcess_MarkAdClickAttributionsAsExpiredForTestingReply
    , NetworkProcess_MergeStatisticForTesting
    , NetworkProcess_MergeStatisticForTestingReply
    , NetworkProcess_PreconnectTo
    , NetworkProcess_PrefetchDNS
    , NetworkProcess_PrepareToSuspend
    , NetworkProcess_PrepareToSuspendReply
    , NetworkProcess_ProcessDidResume
    , NetworkProcess_ProcessDidTransitionToBackground
    , NetworkProcess_ProcessDidTransitionToForeground
    , NetworkProcess_ProcessWillSuspendImminentlyForTestingSync
    , NetworkProcess_PublishDownloadProgress
    , NetworkProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy
    , NetworkProcess_RegisterURLSchemeAsLocal
    , NetworkProcess_RegisterURLSchemeAsNoAccess
    , NetworkProcess_RegisterURLSchemeAsSecure
    , NetworkProcess_RenameOriginInWebsiteData
    , NetworkProcess_RenameOriginInWebsiteDataReply
    , NetworkProcess_ResetCacheMaxAgeCapForPrevalentResources
    , NetworkProcess_ResetCacheMaxAgeCapForPrevalentResourcesReply
    , NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTesting
    , NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTestingReply
    , NetworkProcess_ResetParametersToDefaultValues
    , NetworkProcess_ResetParametersToDefaultValuesReply
    , NetworkProcess_ResetQuota
    , NetworkProcess_ResetQuotaReply
    , NetworkProcess_ResetServiceWorkerFetchTimeoutForTesting
    , NetworkProcess_ResumeDownload
    , NetworkProcess_ScheduleClearInMemoryAndPersistent
    , NetworkProcess_ScheduleClearInMemoryAndPersistentReply
    , NetworkProcess_ScheduleCookieBlockingUpdate
    , NetworkProcess_ScheduleCookieBlockingUpdateReply
    , NetworkProcess_ScheduleStatisticsAndDataRecordsProcessing
    , NetworkProcess_ScheduleStatisticsAndDataRecordsProcessingReply
    , NetworkProcess_SetAdClickAttributionConversionURLForTesting
    , NetworkProcess_SetAdClickAttributionConversionURLForTestingReply
    , NetworkProcess_SetAdClickAttributionDebugMode
    , NetworkProcess_SetAdClickAttributionOverrideTimerForTesting
    , NetworkProcess_SetAdClickAttributionOverrideTimerForTestingReply
    , NetworkProcess_SetAgeCapForClientSideCookies
    , NetworkProcess_SetAgeCapForClientSideCookiesReply
    , NetworkProcess_SetAllowsAnySSLCertificateForWebSocket
    , NetworkProcess_SetAppBoundDomainsForResourceLoadStatistics
    , NetworkProcess_SetAppBoundDomainsForResourceLoadStatisticsReply
    , NetworkProcess_SetCacheMaxAgeCapForPrevalentResources
    , NetworkProcess_SetCacheMaxAgeCapForPrevalentResourcesReply
    , NetworkProcess_SetCacheModel
    , NetworkProcess_SetCacheModelSynchronouslyForTesting
    , NetworkProcess_SetCacheStorageParameters
    , NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTesting
    , NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTestingReply
    , NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTesting
    , NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTestingReply
    , NetworkProcess_SetGrandfathered
    , NetworkProcess_SetGrandfatheredReply
    , NetworkProcess_SetGrandfatheringTime
    , NetworkProcess_SetGrandfatheringTimeReply
    , NetworkProcess_SetIgnoreTLSErrors
    , NetworkProcess_SetIsRunningResourceLoadStatisticsTest
    , NetworkProcess_SetIsRunningResourceLoadStatisticsTestReply
    , NetworkProcess_SetLastSeen
    , NetworkProcess_SetLastSeenReply
    , NetworkProcess_SetMaxStatisticsEntries
    , NetworkProcess_SetMaxStatisticsEntriesReply
    , NetworkProcess_SetMinimumTimeBetweenDataRecordsRemoval
    , NetworkProcess_SetMinimumTimeBetweenDataRecordsRemovalReply
    , NetworkProcess_SetNetworkProxySettings
    , NetworkProcess_SetNotifyPagesWhenDataRecordsWereScanned
    , NetworkProcess_SetNotifyPagesWhenDataRecordsWereScannedReply
    , NetworkProcess_SetNotifyPagesWhenTelemetryWasCaptured
    , NetworkProcess_SetNotifyPagesWhenTelemetryWasCapturedReply
    , NetworkProcess_SetPersistentCredentialStorageEnabled
    , NetworkProcess_SetPrevalentResource
    , NetworkProcess_SetPrevalentResourceForDebugMode
    , NetworkProcess_SetPrevalentResourceForDebugModeReply
    , NetworkProcess_SetPrevalentResourceReply
    , NetworkProcess_SetPruneEntriesDownTo
    , NetworkProcess_SetPruneEntriesDownToReply
    , NetworkProcess_SetQOS
    , NetworkProcess_SetResourceLoadStatisticsDebugMode
    , NetworkProcess_SetResourceLoadStatisticsDebugModeReply
    , NetworkProcess_SetResourceLoadStatisticsEnabled
    , NetworkProcess_SetResourceLoadStatisticsLogTestingEvent
    , NetworkProcess_SetServiceWorkerFetchTimeoutForTesting
    , NetworkProcess_SetSessionIsControlledByAutomation
    , NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemoval
    , NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemovalReply
    , NetworkProcess_SetShouldDowngradeReferrerForTesting
    , NetworkProcess_SetShouldDowngradeReferrerForTestingReply
    , NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTesting
    , NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTestingReply
    , NetworkProcess_SetStorageAccessAPIEnabled
    , NetworkProcess_SetSubframeUnderTopFrameDomain
    , NetworkProcess_SetSubframeUnderTopFrameDomainReply
    , NetworkProcess_SetSubresourceUnderTopFrameDomain
    , NetworkProcess_SetSubresourceUnderTopFrameDomainReply
    , NetworkProcess_SetSubresourceUniqueRedirectFrom
    , NetworkProcess_SetSubresourceUniqueRedirectFromReply
    , NetworkProcess_SetSubresourceUniqueRedirectTo
    , NetworkProcess_SetSubresourceUniqueRedirectToReply
    , NetworkProcess_SetThirdPartyCookieBlockingMode
    , NetworkProcess_SetThirdPartyCookieBlockingModeReply
    , NetworkProcess_SetTimeToLiveUserInteraction
    , NetworkProcess_SetTimeToLiveUserInteractionReply
    , NetworkProcess_SetToSameSiteStrictCookiesForTesting
    , NetworkProcess_SetToSameSiteStrictCookiesForTestingReply
    , NetworkProcess_SetTopFrameUniqueRedirectFrom
    , NetworkProcess_SetTopFrameUniqueRedirectFromReply
    , NetworkProcess_SetTopFrameUniqueRedirectTo
    , NetworkProcess_SetTopFrameUniqueRedirectToReply
    , NetworkProcess_SetUseITPDatabase
    , NetworkProcess_SetUseITPDatabaseReply
    , NetworkProcess_SetVeryPrevalentResource
    , NetworkProcess_SetVeryPrevalentResourceReply
    , NetworkProcess_StatisticsDatabaseHasAllTables
    , NetworkProcess_StatisticsDatabaseHasAllTablesReply
    , NetworkProcess_StoreAdClickAttribution
    , NetworkProcess_SubmitTelemetry
    , NetworkProcess_SubmitTelemetryReply
    , NetworkProcess_SyncAllCookies
    , NetworkProcess_SyncLocalStorage
    , NetworkProcess_UpdateBundleIdentifier
    , NetworkProcess_UpdateBundleIdentifierReply
    , NetworkProcess_UpdatePrevalentDomainsToBlockCookiesFor
    , NetworkProcess_UpdatePrevalentDomainsToBlockCookiesForReply
    , NetworkProcess_UserPreferredLanguagesChanged
    , NetworkRTCMonitor_StartUpdatingIfNeeded
    , NetworkRTCMonitor_StopUpdating
    , NetworkRTCProvider_CloseSocket
    , NetworkRTCProvider_CreateClientTCPSocket
    , NetworkRTCProvider_CreateResolver
    , NetworkRTCProvider_CreateServerTCPSocket
    , NetworkRTCProvider_CreateUDPSocket
    , NetworkRTCProvider_SendToSocket
    , NetworkRTCProvider_SetSocketOption
    , NetworkRTCProvider_StopResolver
    , NetworkRTCProvider_WrapNewTCPConnection
    , NetworkResourceLoader_ContinueDidReceiveResponse
    , NetworkResourceLoader_ContinueWillSendRequest
    , NetworkSocketChannel_Close
    , NetworkSocketChannel_SendData
    , NetworkSocketChannel_SendDataReply
    , NetworkSocketChannel_SendString
    , NetworkSocketChannel_SendStringReply
    , NetworkSocketStream_Close
    , NetworkSocketStream_SendData
    , NetworkSocketStream_SendHandshake
    , PluginControllerProxy_DidEvaluateJavaScript
    , PluginControllerProxy_DidUpdate
    , PluginControllerProxy_FrameDidFail
    , PluginControllerProxy_FrameDidFinishLoading
    , PluginControllerProxy_GeometryDidChange
    , PluginControllerProxy_GetFormValue
    , PluginControllerProxy_GetPluginScriptableNPObject
    , PluginControllerProxy_HandleEditingCommand
    , PluginControllerProxy_HandleKeyboardEvent
    , PluginControllerProxy_HandleMouseEnterEvent
    , PluginControllerProxy_HandleMouseEvent
    , PluginControllerProxy_HandleMouseLeaveEvent
    , PluginControllerProxy_HandleWheelEvent
    , PluginControllerProxy_HandlesPageScaleFactor
    , PluginControllerProxy_IsEditingCommandEnabled
    , PluginControllerProxy_ManualStreamDidFail
    , PluginControllerProxy_ManualStreamDidFinishLoading
    , PluginControllerProxy_ManualStreamDidReceiveData
    , PluginControllerProxy_ManualStreamDidReceiveResponse
    , PluginControllerProxy_MutedStateChanged
    , PluginControllerProxy_PaintEntirePlugin
    , PluginControllerProxy_PrivateBrowsingStateChanged
    , PluginControllerProxy_RequiresUnifiedScaleFactor
    , PluginControllerProxy_SendComplexTextInput
    , PluginControllerProxy_SetFocus
    , PluginControllerProxy_SetLayerHostingMode
    , PluginControllerProxy_Snapshot
    , PluginControllerProxy_StorageBlockingStateChanged
    , PluginControllerProxy_StreamDidFail
    , PluginControllerProxy_StreamDidFinishLoading
    , PluginControllerProxy_StreamDidReceiveData
    , PluginControllerProxy_StreamDidReceiveResponse
    , PluginControllerProxy_StreamWillSendRequest
    , PluginControllerProxy_SupportsSnapshotting
    , PluginControllerProxy_VisibilityDidChange
    , PluginControllerProxy_WindowAndViewFramesChanged
    , PluginControllerProxy_WindowFocusChanged
    , PluginControllerProxy_WindowVisibilityChanged
    , PluginProcessConnectionManager_PluginProcessCrashed
    , PluginProcessConnection_SetException
    , PluginProcessProxy_DidCreateWebProcessConnection
    , PluginProcessProxy_DidDeleteWebsiteData
    , PluginProcessProxy_DidDeleteWebsiteDataForHostNames
    , PluginProcessProxy_DidGetSitesWithData
    , PluginProcessProxy_LaunchApplicationAtURL
    , PluginProcessProxy_LaunchProcess
    , PluginProcessProxy_OpenFile
    , PluginProcessProxy_OpenURL
    , PluginProcessProxy_SetFullscreenWindowIsShowing
    , PluginProcessProxy_SetModalWindowIsShowing
    , PluginProcess_CreateWebProcessConnection
    , PluginProcess_DeleteWebsiteData
    , PluginProcess_DeleteWebsiteDataForHostNames
    , PluginProcess_GetSitesWithData
    , PluginProcess_InitializePluginProcess
    , PluginProcess_SetQOS
    , PluginProxy_CancelManualStreamLoad
    , PluginProxy_CancelStreamLoad
    , PluginProxy_ContinueStreamLoad
    , PluginProxy_CookiesForURL
    , PluginProxy_CreatePluginContainer
    , PluginProxy_DidCreatePlugin
    , PluginProxy_DidFailToCreatePlugin
    , PluginProxy_Evaluate
    , PluginProxy_GetAuthenticationInfo
    , PluginProxy_GetPluginElementNPObject
    , PluginProxy_LoadURL
    , PluginProxy_PluginFocusOrWindowFocusChanged
    , PluginProxy_ProxiesForURL
    , PluginProxy_SetComplexTextInputState
    , PluginProxy_SetCookiesForURL
    , PluginProxy_SetLayerHostingContextID
    , PluginProxy_SetPluginIsPlayingAudio
    , PluginProxy_SetStatusbarText
    , PluginProxy_Update
    , PluginProxy_WindowedPluginGeometryDidChange
    , PluginProxy_WindowedPluginVisibilityDidChange
    , RemoteAudioDestinationManager_CreateAudioDestination
    , RemoteAudioDestinationManager_DeleteAudioDestination
    , RemoteAudioDestinationManager_DeleteAudioDestinationReply
    , RemoteAudioDestinationManager_StartAudioDestination
    , RemoteAudioDestinationManager_StopAudioDestination
    , RemoteAudioDestinationProxy_DidChangeIsPlaying
    , RemoteAudioDestinationProxy_RenderBuffer
    , RemoteAudioDestinationProxy_RenderBufferReply
    , RemoteAudioMediaStreamTrackRendererManager_CreateRenderer
    , RemoteAudioMediaStreamTrackRendererManager_ReleaseRenderer
    , RemoteAudioMediaStreamTrackRenderer_AudioSamplesAvailable
    , RemoteAudioMediaStreamTrackRenderer_AudioSamplesStorageChanged
    , RemoteAudioMediaStreamTrackRenderer_Clear
    , RemoteAudioMediaStreamTrackRenderer_SetVolume
    , RemoteAudioMediaStreamTrackRenderer_Start
    , RemoteAudioMediaStreamTrackRenderer_Stop
    , RemoteAudioSessionProxy_SetCategory
    , RemoteAudioSessionProxy_SetPreferredBufferSize
    , RemoteAudioSessionProxy_TryToSetActive
    , RemoteAudioSession_BeginInterruption
    , RemoteAudioSession_ConfigurationChanged
    , RemoteAudioSession_EndInterruption
    , RemoteCDMFactoryProxy_CreateCDM
    , RemoteCDMFactoryProxy_SupportsKeySystem
    , RemoteCDMInstanceProxy_CreateSession
    , RemoteCDMInstanceProxy_InitializeWithConfiguration
    , RemoteCDMInstanceProxy_InitializeWithConfigurationReply
    , RemoteCDMInstanceProxy_SetServerCertificate
    , RemoteCDMInstanceProxy_SetServerCertificateReply
    , RemoteCDMInstanceProxy_SetStorageDirectory
    , RemoteCDMInstanceSessionProxy_CloseSession
    , RemoteCDMInstanceSessionProxy_CloseSessionReply
    , RemoteCDMInstanceSessionProxy_LoadSession
    , RemoteCDMInstanceSessionProxy_LoadSessionReply
    , RemoteCDMInstanceSessionProxy_RemoveSessionData
    , RemoteCDMInstanceSessionProxy_RemoveSessionDataReply
    , RemoteCDMInstanceSessionProxy_RequestLicense
    , RemoteCDMInstanceSessionProxy_RequestLicenseReply
    , RemoteCDMInstanceSessionProxy_StoreRecordOfKeyUsage
    , RemoteCDMInstanceSessionProxy_UpdateLicense
    , RemoteCDMInstanceSessionProxy_UpdateLicenseReply
    , RemoteCDMInstanceSession_SendMessage
    , RemoteCDMInstanceSession_SessionIdChanged
    , RemoteCDMInstanceSession_UpdateKeyStatuses
    , RemoteCDMProxy_CreateInstance
    , RemoteCDMProxy_GetSupportedConfiguration
    , RemoteCDMProxy_GetSupportedConfigurationReply
    , RemoteCDMProxy_LoadAndInitialize
    , RemoteLegacyCDMFactoryProxy_CreateCDM
    , RemoteLegacyCDMFactoryProxy_SupportsKeySystem
    , RemoteLegacyCDMProxy_CreateSession
    , RemoteLegacyCDMProxy_SetPlayerId
    , RemoteLegacyCDMProxy_SupportsMIMEType
    , RemoteLegacyCDMSessionProxy_CachedKeyForKeyID
    , RemoteLegacyCDMSessionProxy_GenerateKeyRequest
    , RemoteLegacyCDMSessionProxy_ReleaseKeys
    , RemoteLegacyCDMSessionProxy_Update
    , RemoteLegacyCDMSession_SendError
    , RemoteLegacyCDMSession_SendMessage
    , RemoteMediaPlayerManagerProxy_CanDecodeExtendedType
    , RemoteMediaPlayerManagerProxy_ClearMediaCache
    , RemoteMediaPlayerManagerProxy_ClearMediaCacheForOrigins
    , RemoteMediaPlayerManagerProxy_CreateMediaPlayer
    , RemoteMediaPlayerManagerProxy_CreateMediaPlayerReply
    , RemoteMediaPlayerManagerProxy_DeleteMediaPlayer
    , RemoteMediaPlayerManagerProxy_GetSupportedTypes
    , RemoteMediaPlayerManagerProxy_OriginsInMediaCache
    , RemoteMediaPlayerManagerProxy_SupportsKeySystem
    , RemoteMediaPlayerManagerProxy_SupportsTypeAndCodecs
    , RemoteMediaPlayerProxy_AcceleratedRenderingStateChanged
    , RemoteMediaPlayerProxy_AccessLog
    , RemoteMediaPlayerProxy_ApplicationDidBecomeActive
    , RemoteMediaPlayerProxy_ApplicationWillResignActive
    , RemoteMediaPlayerProxy_AttemptToDecryptWithInstance
    , RemoteMediaPlayerProxy_AudioTrackSetEnabled
    , RemoteMediaPlayerProxy_BeginSimulatedHDCPError
    , RemoteMediaPlayerProxy_CancelLoad
    , RemoteMediaPlayerProxy_CdmInstanceAttached
    , RemoteMediaPlayerProxy_CdmInstanceDetached
    , RemoteMediaPlayerProxy_EndSimulatedHDCPError
    , RemoteMediaPlayerProxy_EnterFullscreen
    , RemoteMediaPlayerProxy_EnterFullscreenReply
    , RemoteMediaPlayerProxy_ErrorLog
    , RemoteMediaPlayerProxy_ExitFullscreen
    , RemoteMediaPlayerProxy_ExitFullscreenReply
    , RemoteMediaPlayerProxy_KeyAdded
    , RemoteMediaPlayerProxy_Load
    , RemoteMediaPlayerProxy_LoadReply
    , RemoteMediaPlayerProxy_NotifyActiveSourceBuffersChanged
    , RemoteMediaPlayerProxy_NotifyTrackModeChanged
    , RemoteMediaPlayerProxy_Pause
    , RemoteMediaPlayerProxy_PerformTaskAtMediaTime
    , RemoteMediaPlayerProxy_PerformTaskAtMediaTimeReply
    , RemoteMediaPlayerProxy_Play
    , RemoteMediaPlayerProxy_PrepareForPlayback
    , RemoteMediaPlayerProxy_PrepareForPlaybackReply
    , RemoteMediaPlayerProxy_PrepareForRendering
    , RemoteMediaPlayerProxy_PrepareToPlay
    , RemoteMediaPlayerProxy_Seek
    , RemoteMediaPlayerProxy_SeekWithTolerance
    , RemoteMediaPlayerProxy_SetBufferingPolicy
    , RemoteMediaPlayerProxy_SetLegacyCDMSession
    , RemoteMediaPlayerProxy_SetMuted
    , RemoteMediaPlayerProxy_SetPreload
    , RemoteMediaPlayerProxy_SetPreservesPitch
    , RemoteMediaPlayerProxy_SetPrivateBrowsingMode
    , RemoteMediaPlayerProxy_SetRate
    , RemoteMediaPlayerProxy_SetShouldContinueAfterKeyNeeded
    , RemoteMediaPlayerProxy_SetShouldDisableSleep
    , RemoteMediaPlayerProxy_SetShouldMaintainAspectRatio
    , RemoteMediaPlayerProxy_SetShouldPlayToPlaybackTarget
    , RemoteMediaPlayerProxy_SetVideoFullscreenFrameFenced
    , RemoteMediaPlayerProxy_SetVideoFullscreenGravity
    , RemoteMediaPlayerProxy_SetVideoFullscreenMode
    , RemoteMediaPlayerProxy_SetVideoInlineSizeFenced
    , RemoteMediaPlayerProxy_SetVisible
    , RemoteMediaPlayerProxy_SetVolume
    , RemoteMediaPlayerProxy_SetWirelessPlaybackTarget
    , RemoteMediaPlayerProxy_SetWirelessVideoPlaybackDisabled
    , RemoteMediaPlayerProxy_SyncTextTrackBounds
    , RemoteMediaPlayerProxy_TextTrackSetMode
    , RemoteMediaPlayerProxy_TracksChanged
    , RemoteMediaPlayerProxy_UpdateVideoFullscreenInlineImage
    , RemoteMediaPlayerProxy_VideoFullscreenStandbyChanged
    , RemoteMediaPlayerProxy_VideoTrackSetSelected
    , RemoteMediaPlayerProxy_WouldTaintOrigin
    , RemoteMediaRecorderManager_CreateRecorder
    , RemoteMediaRecorderManager_CreateRecorderReply
    , RemoteMediaRecorderManager_ReleaseRecorder
    , RemoteMediaRecorder_AudioSamplesAvailable
    , RemoteMediaRecorder_AudioSamplesStorageChanged
    , RemoteMediaRecorder_FetchData
    , RemoteMediaRecorder_FetchDataReply
    , RemoteMediaRecorder_StopRecording
    , RemoteMediaRecorder_VideoSampleAvailable
    , RemoteMediaResourceManager_AccessControlCheckFailed
    , RemoteMediaResourceManager_DataReceived
    , RemoteMediaResourceManager_DataSent
    , RemoteMediaResourceManager_LoadFailed
    , RemoteMediaResourceManager_LoadFinished
    , RemoteMediaResourceManager_RedirectReceived
    , RemoteMediaResourceManager_RedirectReceivedReply
    , RemoteMediaResourceManager_ResponseReceived
    , RemoteMediaResourceManager_ResponseReceivedReply
    , RemoteRenderingBackendProxy_CreateImageBuffer
    , RemoteRenderingBackendProxy_FlushImageBufferDrawingContext
    , RemoteRenderingBackendProxy_FlushImageBufferDrawingContextAndCommit
    , RemoteRenderingBackendProxy_GetImageData
    , RemoteRenderingBackendProxy_ReleaseImageBuffer
    , RemoteRenderingBackend_CommitImageBufferFlushContext
    , RemoteRenderingBackend_CreateImageBufferBackend
    , RemoteSampleBufferDisplayLayerManager_CreateLayer
    , RemoteSampleBufferDisplayLayerManager_CreateLayerReply
    , RemoteSampleBufferDisplayLayerManager_ReleaseLayer
    , RemoteSampleBufferDisplayLayer_ClearEnqueuedSamples
    , RemoteSampleBufferDisplayLayer_EnqueueSample
    , RemoteSampleBufferDisplayLayer_Flush
    , RemoteSampleBufferDisplayLayer_FlushAndRemoveImage
    , RemoteSampleBufferDisplayLayer_UpdateAffineTransform
    , RemoteSampleBufferDisplayLayer_UpdateBoundsAndPosition
    , RemoteSampleBufferDisplayLayer_UpdateDisplayMode
    , RemoteWebInspectorProxy_Append
    , RemoteWebInspectorProxy_BringToFront
    , RemoteWebInspectorProxy_FrontendDidClose
    , RemoteWebInspectorProxy_OpenInNewTab
    , RemoteWebInspectorProxy_Reopen
    , RemoteWebInspectorProxy_ResetState
    , RemoteWebInspectorProxy_Save
    , RemoteWebInspectorProxy_SendMessageToBackend
    , RemoteWebInspectorProxy_SetForcedAppearance
    , RemoteWebInspectorProxy_SetSheetRect
    , RemoteWebInspectorProxy_ShowCertificate
    , RemoteWebInspectorProxy_StartWindowDrag
    , RemoteWebInspectorUI_DidAppend
    , RemoteWebInspectorUI_DidSave
    , RemoteWebInspectorUI_Initialize
    , RemoteWebInspectorUI_SendMessageToFrontend
    , RemoteWebInspectorUI_SetDiagnosticLoggingAvailable
    , RemoteWebInspectorUI_UpdateFindString
    , SampleBufferDisplayLayer_SetDidFail
    , ServiceWorkerFetchTask_DidFail
    , ServiceWorkerFetchTask_DidFinish
    , ServiceWorkerFetchTask_DidNotHandle
    , ServiceWorkerFetchTask_DidReceiveData
    , ServiceWorkerFetchTask_DidReceiveFormData
    , ServiceWorkerFetchTask_DidReceiveRedirectResponse
    , ServiceWorkerFetchTask_DidReceiveResponse
    , ServiceWorkerFetchTask_DidReceiveSharedBuffer
    , StorageAreaMap_ClearCache
    , StorageAreaMap_DidClear
    , StorageAreaMap_DidRemoveItem
    , StorageAreaMap_DidSetItem
    , StorageAreaMap_DispatchStorageEvent
    , StorageManagerSet_Clear
    , StorageManagerSet_CloneSessionStorageNamespace
    , StorageManagerSet_ConnectToLocalStorageArea
    , StorageManagerSet_ConnectToSessionStorageArea
    , StorageManagerSet_ConnectToTransientLocalStorageArea
    , StorageManagerSet_DisconnectFromStorageArea
    , StorageManagerSet_GetValues
    , StorageManagerSet_RemoveItem
    , StorageManagerSet_SetItem
    , ViewGestureController_DidCollectGeometryForMagnificationGesture
    , ViewGestureController_DidCollectGeometryForSmartMagnificationGesture
    , ViewGestureController_DidHitRenderTreeSizeThreshold
    , ViewGestureGeometryCollector_CollectGeometryForMagnificationGesture
    , ViewGestureGeometryCollector_CollectGeometryForSmartMagnificationGesture
    , ViewGestureGeometryCollector_SetRenderTreeSizeNotificationThreshold
    , VisitedLinkStore_AddVisitedLinkHashFromPage
    , VisitedLinkTableController_AllVisitedLinkStateChanged
    , VisitedLinkTableController_RemoveAllVisitedLinks
    , VisitedLinkTableController_SetVisitedLinkTable
    , VisitedLinkTableController_VisitedLinkStateChanged
    , WebAutomationSessionProxy_ComputeElementLayout
    , WebAutomationSessionProxy_ComputeElementLayoutReply
    , WebAutomationSessionProxy_DeleteCookie
    , WebAutomationSessionProxy_DeleteCookieReply
    , WebAutomationSessionProxy_EvaluateJavaScriptFunction
    , WebAutomationSessionProxy_FocusFrame
    , WebAutomationSessionProxy_GetCookiesForFrame
    , WebAutomationSessionProxy_GetCookiesForFrameReply
    , WebAutomationSessionProxy_ResolveChildFrameWithName
    , WebAutomationSessionProxy_ResolveChildFrameWithNameReply
    , WebAutomationSessionProxy_ResolveChildFrameWithNodeHandle
    , WebAutomationSessionProxy_ResolveChildFrameWithNodeHandleReply
    , WebAutomationSessionProxy_ResolveChildFrameWithOrdinal
    , WebAutomationSessionProxy_ResolveChildFrameWithOrdinalReply
    , WebAutomationSessionProxy_ResolveParentFrame
    , WebAutomationSessionProxy_ResolveParentFrameReply
    , WebAutomationSessionProxy_SelectOptionElement
    , WebAutomationSessionProxy_SelectOptionElementReply
    , WebAutomationSessionProxy_SetFilesForInputFileUpload
    , WebAutomationSessionProxy_SetFilesForInputFileUploadReply
    , WebAutomationSessionProxy_SnapshotRectForScreenshot
    , WebAutomationSessionProxy_SnapshotRectForScreenshotReply
    , WebAutomationSessionProxy_TakeScreenshot
    , WebAutomationSession_DidEvaluateJavaScriptFunction
    , WebAutomationSession_DidTakeScreenshot
    , WebConnection_HandleMessage
    , WebCookieManagerProxy_CookiesDidChange
    , WebCookieManager_DeleteAllCookies
    , WebCookieManager_DeleteAllCookiesModifiedSince
    , WebCookieManager_DeleteAllCookiesModifiedSinceReply
    , WebCookieManager_DeleteCookie
    , WebCookieManager_DeleteCookieReply
    , WebCookieManager_DeleteCookiesForHostnames
    , WebCookieManager_GetAllCookies
    , WebCookieManager_GetAllCookiesReply
    , WebCookieManager_GetCookies
    , WebCookieManager_GetCookiesReply
    , WebCookieManager_GetHTTPCookieAcceptPolicy
    , WebCookieManager_GetHTTPCookieAcceptPolicyReply
    , WebCookieManager_GetHostnamesWithCookies
    , WebCookieManager_GetHostnamesWithCookiesReply
    , WebCookieManager_SetCookie
    , WebCookieManager_SetCookiePersistentStorage
    , WebCookieManager_SetCookieReply
    , WebCookieManager_SetCookies
    , WebCookieManager_SetCookiesReply
    , WebCookieManager_SetHTTPCookieAcceptPolicy
    , WebCookieManager_SetHTTPCookieAcceptPolicyReply
    , WebCookieManager_StartObservingCookieChanges
    , WebCookieManager_StopObservingCookieChanges
    , WebFullScreenManagerProxy_BeganEnterFullScreen
    , WebFullScreenManagerProxy_BeganExitFullScreen
    , WebFullScreenManagerProxy_Close
    , WebFullScreenManagerProxy_EnterFullScreen
    , WebFullScreenManagerProxy_ExitFullScreen
    , WebFullScreenManagerProxy_SupportsFullScreen
    , WebFullScreenManager_DidEnterFullScreen
    , WebFullScreenManager_DidExitFullScreen
    , WebFullScreenManager_RequestExitFullScreen
    , WebFullScreenManager_RestoreScrollPosition
    , WebFullScreenManager_SaveScrollPosition
    , WebFullScreenManager_SetAnimatingFullScreen
    , WebFullScreenManager_SetFullscreenAutoHideDuration
    , WebFullScreenManager_SetFullscreenControlsHidden
    , WebFullScreenManager_SetFullscreenInsets
    , WebFullScreenManager_WillEnterFullScreen
    , WebFullScreenManager_WillExitFullScreen
    , WebGeolocationManagerProxy_SetEnableHighAccuracy
    , WebGeolocationManagerProxy_StartUpdating
    , WebGeolocationManagerProxy_StopUpdating
    , WebGeolocationManager_DidChangePosition
    , WebGeolocationManager_DidFailToDeterminePosition
    , WebGeolocationManager_ResetPermissions
    , WebIDBConnectionToServer_DidAbortTransaction
    , WebIDBConnectionToServer_DidClearObjectStore
    , WebIDBConnectionToServer_DidCloseFromServer
    , WebIDBConnectionToServer_DidCommitTransaction
    , WebIDBConnectionToServer_DidCreateIndex
    , WebIDBConnectionToServer_DidCreateObjectStore
    , WebIDBConnectionToServer_DidDeleteDatabase
    , WebIDBConnectionToServer_DidDeleteIndex
    , WebIDBConnectionToServer_DidDeleteObjectStore
    , WebIDBConnectionToServer_DidDeleteRecord
    , WebIDBConnectionToServer_DidGetAllDatabaseNamesAndVersions
    , WebIDBConnectionToServer_DidGetAllRecords
    , WebIDBConnectionToServer_DidGetCount
    , WebIDBConnectionToServer_DidGetRecord
    , WebIDBConnectionToServer_DidIterateCursor
    , WebIDBConnectionToServer_DidOpenCursor
    , WebIDBConnectionToServer_DidOpenDatabase
    , WebIDBConnectionToServer_DidPutOrAdd
    , WebIDBConnectionToServer_DidRenameIndex
    , WebIDBConnectionToServer_DidRenameObjectStore
    , WebIDBConnectionToServer_DidStartTransaction
    , WebIDBConnectionToServer_FireVersionChangeEvent
    , WebIDBConnectionToServer_NotifyOpenDBRequestBlocked
    , WebIDBServer_AbortOpenAndUpgradeNeeded
    , WebIDBServer_AbortTransaction
    , WebIDBServer_ClearObjectStore
    , WebIDBServer_CommitTransaction
    , WebIDBServer_CreateIndex
    , WebIDBServer_CreateObjectStore
    , WebIDBServer_DatabaseConnectionClosed
    , WebIDBServer_DatabaseConnectionPendingClose
    , WebIDBServer_DeleteDatabase
    , WebIDBServer_DeleteIndex
    , WebIDBServer_DeleteObjectStore
    , WebIDBServer_DeleteRecord
    , WebIDBServer_DidFinishHandlingVersionChangeTransaction
    , WebIDBServer_DidFireVersionChangeEvent
    , WebIDBServer_EstablishTransaction
    , WebIDBServer_GetAllDatabaseNamesAndVersions
    , WebIDBServer_GetAllRecords
    , WebIDBServer_GetCount
    , WebIDBServer_GetRecord
    , WebIDBServer_IterateCursor
    , WebIDBServer_OpenCursor
    , WebIDBServer_OpenDBRequestCancelled
    , WebIDBServer_OpenDatabase
    , WebIDBServer_PutOrAdd
    , WebIDBServer_RenameIndex
    , WebIDBServer_RenameObjectStore
    , WebInspectorInterruptDispatcher_NotifyNeedDebuggerBreak
    , WebInspectorProxy_Append
    , WebInspectorProxy_AttachAvailabilityChanged
    , WebInspectorProxy_AttachBottom
    , WebInspectorProxy_AttachLeft
    , WebInspectorProxy_AttachRight
    , WebInspectorProxy_BringInspectedPageToFront
    , WebInspectorProxy_BringToFront
    , WebInspectorProxy_Detach
    , WebInspectorProxy_DidClose
    , WebInspectorProxy_ElementSelectionChanged
    , WebInspectorProxy_FrontendLoaded
    , WebInspectorProxy_InspectedURLChanged
    , WebInspectorProxy_OpenLocalInspectorFrontend
    , WebInspectorProxy_Reopen
    , WebInspectorProxy_ResetState
    , WebInspectorProxy_Save
    , WebInspectorProxy_SendMessageToBackend
    , WebInspectorProxy_SetAttachedWindowHeight
    , WebInspectorProxy_SetAttachedWindowWidth
    , WebInspectorProxy_SetDeveloperPreferenceOverride
    , WebInspectorProxy_SetForcedAppearance
    , WebInspectorProxy_SetFrontendConnection
    , WebInspectorProxy_SetSheetRect
    , WebInspectorProxy_ShowCertificate
    , WebInspectorProxy_StartWindowDrag
    , WebInspectorProxy_TimelineRecordingChanged
    , WebInspectorUI_AttachedBottom
    , WebInspectorUI_AttachedLeft
    , WebInspectorUI_AttachedRight
    , WebInspectorUI_Detached
    , WebInspectorUI_DidAppend
    , WebInspectorUI_DidSave
    , WebInspectorUI_EstablishConnection
    , WebInspectorUI_SendMessageToFrontend
    , WebInspectorUI_SetDiagnosticLoggingAvailable
    , WebInspectorUI_SetDockingUnavailable
    , WebInspectorUI_SetIsVisible
    , WebInspectorUI_ShowConsole
    , WebInspectorUI_ShowMainResourceForFrame
    , WebInspectorUI_ShowResources
    , WebInspectorUI_StartElementSelection
    , WebInspectorUI_StartPageProfiling
    , WebInspectorUI_StopElementSelection
    , WebInspectorUI_StopPageProfiling
    , WebInspectorUI_UpdateConnection
    , WebInspectorUI_UpdateFindString
    , WebInspector_Close
    , WebInspector_OpenInNewTab
    , WebInspector_SetAttached
    , WebInspector_SetFrontendConnection
    , WebInspector_Show
    , WebInspector_ShowConsole
    , WebInspector_ShowMainResourceForFrame
    , WebInspector_ShowResources
    , WebInspector_StartElementSelection
    , WebInspector_StartPageProfiling
    , WebInspector_StopElementSelection
    , WebInspector_StopPageProfiling
    , WebMDNSRegister_FinishedRegisteringMDNSName
    , WebNotificationManager_DidClickNotification
    , WebNotificationManager_DidCloseNotifications
    , WebNotificationManager_DidRemoveNotificationDecisions
    , WebNotificationManager_DidShowNotification
    , WebNotificationManager_DidUpdateNotificationDecision
    , WebPageProxy_AccessibilityScreenToRootView
    , WebPageProxy_AddMediaUsageManagerSession
    , WebPageProxy_AddPlaybackTargetPickerClient
    , WebPageProxy_ApplicationManifestCallback
    , WebPageProxy_AssistiveTechnologyMakeFirstResponder
    , WebPageProxy_AttributedStringForCharacterRangeCallback
    , WebPageProxy_BackForwardAddItem
    , WebPageProxy_BackForwardClear
    , WebPageProxy_BackForwardGoToItem
    , WebPageProxy_BackForwardItemAtIndex
    , WebPageProxy_BackForwardListCounts
    , WebPageProxy_BeginMonitoringCaptureDevices
    , WebPageProxy_BindAccessibilityTree
    , WebPageProxy_BoolCallback
    , WebPageProxy_CanUndoRedo
    , WebPageProxy_CancelNotification
    , WebPageProxy_CheckGrammarOfString
    , WebPageProxy_CheckSpellingOfString
    , WebPageProxy_CheckTextOfParagraph
    , WebPageProxy_ClearAllEditCommands
    , WebPageProxy_ClearNotifications
    , WebPageProxy_ClearTextIndicator
    , WebPageProxy_CloneAttachmentData
    , WebPageProxy_ClosePage
    , WebPageProxy_CommitPotentialTapFailed
    , WebPageProxy_CompositionWasCanceled
    , WebPageProxy_ComputedPagesCallback
    , WebPageProxy_ConfigureLoggingChannel
    , WebPageProxy_ContentFilterDidBlockLoadForFrame
    , WebPageProxy_ContentRuleListNotification
    , WebPageProxy_CouldNotRestorePageState
    , WebPageProxy_CreateInspectorTarget
    , WebPageProxy_CreateNewPage
    , WebPageProxy_CreatePluginContainer
    , WebPageProxy_DataCallback
    , WebPageProxy_DecidePolicyForNavigationActionAsync
    , WebPageProxy_DecidePolicyForNavigationActionSync
    , WebPageProxy_DecidePolicyForNewWindowAction
    , WebPageProxy_DecidePolicyForResponse
    , WebPageProxy_DestroyInspectorTarget
    , WebPageProxy_DictationAlternatives
    , WebPageProxy_DidBlockInsecurePluginVersion
    , WebPageProxy_DidCancelClientRedirectForFrame
    , WebPageProxy_DidChangeContentSize
    , WebPageProxy_DidChangeInspectorFrontendCount
    , WebPageProxy_DidChangeIntrinsicContentSize
    , WebPageProxy_DidChangeMainDocument
    , WebPageProxy_DidChangePageCount
    , WebPageProxy_DidChangeProgress
    , WebPageProxy_DidChangeProvisionalURLForFrame
    , WebPageProxy_DidChangeScrollOffsetPinningForMainFrame
    , WebPageProxy_DidChangeScrollbarsForMainFrame
    , WebPageProxy_DidChangeViewportProperties
    , WebPageProxy_DidCommitLoadForFrame
    , WebPageProxy_DidCompleteSyntheticClick
    , WebPageProxy_DidCountStringMatches
    , WebPageProxy_DidCreateContextForVisibilityPropagation
    , WebPageProxy_DidCreateMainFrame
    , WebPageProxy_DidCreateSubframe
    , WebPageProxy_DidCreateWindow
    , WebPageProxy_DidDestroyNavigation
    , WebPageProxy_DidDestroyNotification
    , WebPageProxy_DidDetectXSSForFrame
    , WebPageProxy_DidDisplayInsecureContentForFrame
    , WebPageProxy_DidEndDragging
    , WebPageProxy_DidExplicitOpenForFrame
    , WebPageProxy_DidFailLoadForFrame
    , WebPageProxy_DidFailProvisionalLoadForFrame
    , WebPageProxy_DidFailToFindString
    , WebPageProxy_DidFailToInitializePlugin
    , WebPageProxy_DidFailToSuspendAfterProcessSwap
    , WebPageProxy_DidFindString
    , WebPageProxy_DidFindStringMatches
    , WebPageProxy_DidFindTextManipulationItems
    , WebPageProxy_DidFinishDocumentLoadForFrame
    , WebPageProxy_DidFinishLoadForFrame
    , WebPageProxy_DidFinishLoadForQuickLookDocumentInMainFrame
    , WebPageProxy_DidFinishLoadingDataForCustomContentProvider
    , WebPageProxy_DidFinishProgress
    , WebPageProxy_DidFirstLayoutForFrame
    , WebPageProxy_DidFirstVisuallyNonEmptyLayoutForFrame
    , WebPageProxy_DidGetImageForFindMatch
    , WebPageProxy_DidGetTapHighlightGeometries
    , WebPageProxy_DidHandleAcceptedCandidate
    , WebPageProxy_DidHandleAdditionalDragItemsRequest
    , WebPageProxy_DidHandleDragStartRequest
    , WebPageProxy_DidInsertAttachmentWithIdentifier
    , WebPageProxy_DidNavigateWithNavigationData
    , WebPageProxy_DidNotHandleTapAsClick
    , WebPageProxy_DidPerformClientRedirect
    , WebPageProxy_DidPerformDictionaryLookup
    , WebPageProxy_DidPerformDragControllerAction
    , WebPageProxy_DidPerformDragOperation
    , WebPageProxy_DidPerformImmediateActionHitTest
    , WebPageProxy_DidPerformServerRedirect
    , WebPageProxy_DidReachLayoutMilestone
    , WebPageProxy_DidReceiveEditDragSnapshot
    , WebPageProxy_DidReceiveEvent
    , WebPageProxy_DidReceivePositionInformation
    , WebPageProxy_DidReceiveServerRedirectForProvisionalLoadForFrame
    , WebPageProxy_DidReceiveTitleForFrame
    , WebPageProxy_DidRemoveAttachmentWithIdentifier
    , WebPageProxy_DidResignInputElementStrongPasswordAppearance
    , WebPageProxy_DidRestoreScrollPosition
    , WebPageProxy_DidRunInsecureContentForFrame
    , WebPageProxy_DidSameDocumentNavigationForFrame
    , WebPageProxy_DidStartLoadForQuickLookDocumentInMainFrame
    , WebPageProxy_DidStartProgress
    , WebPageProxy_DidStartProvisionalLoadForFrame
    , WebPageProxy_DidSuspendAfterProcessSwap
    , WebPageProxy_DidUpdateActivityState
    , WebPageProxy_DidUpdateHistoryTitle
    , WebPageProxy_DisableDoubleTapGesturesDuringTapIfNecessary
    , WebPageProxy_DisableInspectorNodeSearch
    , WebPageProxy_DismissCorrectionPanel
    , WebPageProxy_DismissCorrectionPanelSoon
    , WebPageProxy_DrawToPDFCallback
    , WebPageProxy_EditorStateChanged
    , WebPageProxy_ElementDidBlur
    , WebPageProxy_ElementDidFocus
    , WebPageProxy_EnableInspectorNodeSearch
    , WebPageProxy_EndColorPicker
    , WebPageProxy_EndDataListSuggestions
    , WebPageProxy_EnumerateMediaDevicesForFrame
    , WebPageProxy_EnumerateMediaDevicesForFrameReply
    , WebPageProxy_ExceededDatabaseQuota
    , WebPageProxy_ExecuteSavedCommandBySelector
    , WebPageProxy_ExecuteUndoRedo
    , WebPageProxy_FindPlugin
    , WebPageProxy_FinishedLoadingIcon
    , WebPageProxy_FixedLayoutSizeDidChange
    , WebPageProxy_FocusedContentMediaElementDidChange
    , WebPageProxy_FocusedElementDidChangeInputMode
    , WebPageProxy_FocusedElementInformationCallback
    , WebPageProxy_FocusedFrameChanged
    , WebPageProxy_FontAtSelectionCallback
    , WebPageProxy_FontAttributesCallback
    , WebPageProxy_GestureCallback
    , WebPageProxy_GetGuessesForWord
    , WebPageProxy_GetIsSpeaking
    , WebPageProxy_GetLoadDecisionForIcon
    , WebPageProxy_GetMenuBarIsVisible
    , WebPageProxy_GetStatusBarIsVisible
    , WebPageProxy_GetToolbarsAreVisible
    , WebPageProxy_GetWindowFrame
    , WebPageProxy_HandleAutoFillButtonClick
    , WebPageProxy_HandleAutocorrectionContext
    , WebPageProxy_HandleAutoplayEvent
    , WebPageProxy_HandleKeydownInDataList
    , WebPageProxy_HandleMessage
    , WebPageProxy_HandleSmartMagnificationInformationForPotentialTap
    , WebPageProxy_HandleSynchronousMessage
    , WebPageProxy_HasMediaSessionWithActiveMediaElementsDidChange
    , WebPageProxy_HideInspectorHighlight
    , WebPageProxy_HideInspectorIndication
    , WebPageProxy_HidePopupMenu
    , WebPageProxy_HideValidationMessage
    , WebPageProxy_IgnoreWord
    , WebPageProxy_ImageCallback
    , WebPageProxy_ImageOrMediaDocumentSizeChanged
    , WebPageProxy_InterpretKeyEvent
    , WebPageProxy_InvalidateStringCallback
    , WebPageProxy_IsPlayingMediaDidChange
    , WebPageProxy_LearnWord
    , WebPageProxy_LoadRecentSearches
    , WebPageProxy_LoadSynchronousURLSchemeTask
    , WebPageProxy_LogDiagnosticMessage
    , WebPageProxy_LogDiagnosticMessageWithEnhancedPrivacy
    , WebPageProxy_LogDiagnosticMessageWithResult
    , WebPageProxy_LogDiagnosticMessageWithValue
    , WebPageProxy_LogDiagnosticMessageWithValueDictionary
    , WebPageProxy_LogScrollingEvent
    , WebPageProxy_MainFramePluginHandlesPageScaleGestureDidChange
    , WebPageProxy_MakeFirstResponder
    , WebPageProxy_MediaSessionMetadataDidChange
    , WebPageProxy_MockMediaPlaybackTargetPickerDismissPopup
    , WebPageProxy_MouseDidMoveOverElement
    , WebPageProxy_NotifyScrollerThumbIsVisibleInRect
    , WebPageProxy_NowPlayingInfoCallback
    , WebPageProxy_OpenPDFFromTemporaryFolderWithNativeApplication
    , WebPageProxy_PageDidScroll
    , WebPageProxy_PageExtendedBackgroundColorDidChange
    , WebPageProxy_PageScaleFactorDidChange
    , WebPageProxy_PlaybackTargetPickerClientStateDidChange
    , WebPageProxy_PluginFocusOrWindowFocusChanged
    , WebPageProxy_PluginScaleFactorDidChange
    , WebPageProxy_PluginZoomFactorDidChange
    , WebPageProxy_PrintFinishedCallback
    , WebPageProxy_PrintFrame
    , WebPageProxy_ReachedApplicationCacheOriginQuota
    , WebPageProxy_RecommendedScrollbarStyleDidChange
    , WebPageProxy_RecordAutocorrectionResponse
    , WebPageProxy_RectForCharacterRangeCallback
    , WebPageProxy_RegisterAttachmentIdentifier
    , WebPageProxy_RegisterAttachmentIdentifierFromData
    , WebPageProxy_RegisterAttachmentIdentifierFromFilePath
    , WebPageProxy_RegisterAttachmentsFromSerializedData
    , WebPageProxy_RegisterEditCommandForUndo
    , WebPageProxy_RegisterInsertionUndoGrouping
    , WebPageProxy_RegisterWebProcessAccessibilityToken
    , WebPageProxy_RemoveDictationAlternatives
    , WebPageProxy_RemoveMediaUsageManagerSession
    , WebPageProxy_RemovePlaybackTargetPickerClient
    , WebPageProxy_RequestCheckingOfString
    , WebPageProxy_RequestDOMPasteAccess
    , WebPageProxy_RequestGeolocationPermissionForFrame
    , WebPageProxy_RequestInstallMissingMediaPlugins
    , WebPageProxy_RequestNotificationPermission
    , WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrame
    , WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrameReply
    , WebPageProxy_RequestPointerLock
    , WebPageProxy_RequestPointerUnlock
    , WebPageProxy_RequestUserMediaPermissionForFrame
    , WebPageProxy_ResolveWebGLPolicyForURL
    , WebPageProxy_RestorePageCenterAndScale
    , WebPageProxy_RestorePageState
    , WebPageProxy_RevokeGeolocationAuthorizationToken
    , WebPageProxy_RootViewToAccessibilityScreen
    , WebPageProxy_RootViewToScreen
    , WebPageProxy_RunBeforeUnloadConfirmPanel
    , WebPageProxy_RunJavaScriptAlert
    , WebPageProxy_RunJavaScriptConfirm
    , WebPageProxy_RunJavaScriptPrompt
    , WebPageProxy_RunModal
    , WebPageProxy_RunOpenPanel
    , WebPageProxy_SaveImageToLibrary
    , WebPageProxy_SavePDFToFileInDownloadsFolder
    , WebPageProxy_SavePDFToTemporaryFolderAndOpenWithNativeApplication
    , WebPageProxy_SaveRecentSearches
    , WebPageProxy_ScreenToRootView
    , WebPageProxy_ScriptValueCallback
    , WebPageProxy_ScrollingNodeScrollDidEndScroll
    , WebPageProxy_ScrollingNodeScrollWillStartScroll
    , WebPageProxy_SearchTheWeb
    , WebPageProxy_SearchWithSpotlight
    , WebPageProxy_SelectionContextCallback
    , WebPageProxy_SelectionRectsCallback
    , WebPageProxy_SendMessageToInspectorFrontend
    , WebPageProxy_SendMessageToWebView
    , WebPageProxy_SendMessageToWebViewWithReply
    , WebPageProxy_SendMessageToWebViewWithReplyReply
    , WebPageProxy_SerializedAttachmentDataForIdentifiers
    , WebPageProxy_SetCanShortCircuitHorizontalWheelEvents
    , WebPageProxy_SetColorPickerColor
    , WebPageProxy_SetCursor
    , WebPageProxy_SetCursorHiddenUntilMouseMoves
    , WebPageProxy_SetDataDetectionResult
    , WebPageProxy_SetEditableElementIsFocused
    , WebPageProxy_SetFocus
    , WebPageProxy_SetHasExecutedAppBoundBehaviorBeforeNavigation
    , WebPageProxy_SetHasHadSelectionChangesFromUserInteraction
    , WebPageProxy_SetInputMethodState
    , WebPageProxy_SetIsNeverRichlyEditableForTouchBar
    , WebPageProxy_SetIsResizable
    , WebPageProxy_SetIsTouchBarUpdateSupressedForHiddenContentEditable
    , WebPageProxy_SetIsUsingHighPerformanceWebGL
    , WebPageProxy_SetMenuBarIsVisible
    , WebPageProxy_SetMockMediaPlaybackTargetPickerEnabled
    , WebPageProxy_SetMockMediaPlaybackTargetPickerState
    , WebPageProxy_SetMockVideoPresentationModeEnabled
    , WebPageProxy_SetMockWebAuthenticationConfiguration
    , WebPageProxy_SetNetworkRequestsInProgress
    , WebPageProxy_SetPluginComplexTextInputState
    , WebPageProxy_SetPromisedDataForImage
    , WebPageProxy_SetRenderTreeSize
    , WebPageProxy_SetStatusBarIsVisible
    , WebPageProxy_SetStatusText
    , WebPageProxy_SetTextIndicator
    , WebPageProxy_SetToolbarsAreVisible
    , WebPageProxy_SetWindowFrame
    , WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccess
    , WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccessReply
    , WebPageProxy_ShowColorPicker
    , WebPageProxy_ShowContextMenu
    , WebPageProxy_ShowCorrectionPanel
    , WebPageProxy_ShowDataDetectorsUIForPositionInformation
    , WebPageProxy_ShowDataListSuggestions
    , WebPageProxy_ShowDictationAlternativeUI
    , WebPageProxy_ShowEmojiPicker
    , WebPageProxy_ShowEmojiPickerReply
    , WebPageProxy_ShowInspectorHighlight
    , WebPageProxy_ShowInspectorIndication
    , WebPageProxy_ShowNotification
    , WebPageProxy_ShowPDFContextMenu
    , WebPageProxy_ShowPage
    , WebPageProxy_ShowPlaybackTargetPicker
    , WebPageProxy_ShowPopupMenu
    , WebPageProxy_ShowShareSheet
    , WebPageProxy_ShowShareSheetReply
    , WebPageProxy_ShowTelephoneNumberMenu
    , WebPageProxy_ShowValidationMessage
    , WebPageProxy_SignedPublicKeyAndChallengeString
    , WebPageProxy_Speak
    , WebPageProxy_SpeechSynthesisCancel
    , WebPageProxy_SpeechSynthesisPause
    , WebPageProxy_SpeechSynthesisPauseReply
    , WebPageProxy_SpeechSynthesisResume
    , WebPageProxy_SpeechSynthesisResumeReply
    , WebPageProxy_SpeechSynthesisSetFinishedCallback
    , WebPageProxy_SpeechSynthesisSetFinishedCallbackReply
    , WebPageProxy_SpeechSynthesisSpeak
    , WebPageProxy_SpeechSynthesisSpeakReply
    , WebPageProxy_SpeechSynthesisVoiceList
    , WebPageProxy_SpellingUIIsShowing
    , WebPageProxy_StartDrag
    , WebPageProxy_StartURLSchemeTask
    , WebPageProxy_StopSpeaking
    , WebPageProxy_StopURLSchemeTask
    , WebPageProxy_StringCallback
    , WebPageProxy_SubstitutionsPanelIsShowing
    , WebPageProxy_TakeFocus
    , WebPageProxy_TouchBarMenuDataChanged
    , WebPageProxy_TouchBarMenuItemDataAdded
    , WebPageProxy_TouchBarMenuItemDataRemoved
    , WebPageProxy_TouchesCallback
    , WebPageProxy_UnableToImplementPolicy
    , WebPageProxy_UnavailablePluginButtonClicked
    , WebPageProxy_UnsignedCallback
    , WebPageProxy_UnwrapCryptoKey
    , WebPageProxy_UpdateInputContextAfterBlurringAndRefocusingElement
    , WebPageProxy_UpdateMediaUsageManagerSessionState
    , WebPageProxy_UpdateSpellingUIWithGrammarString
    , WebPageProxy_UpdateSpellingUIWithMisspelledWord
    , WebPageProxy_UpdateStringForFind
    , WebPageProxy_UseFixedLayoutDidChange
    , WebPageProxy_ValidateCommandCallback
    , WebPageProxy_VoidCallback
    , WebPageProxy_WebGLPolicyForURL
    , WebPageProxy_WillGoToBackForwardListItem
    , WebPageProxy_WillPerformClientRedirectForFrame
    , WebPageProxy_WillReceiveEditDragSnapshot
    , WebPageProxy_WillSubmitForm
    , WebPageProxy_WindowedPluginGeometryDidChange
    , WebPageProxy_WindowedPluginVisibilityDidChange
    , WebPageProxy_WrapCryptoKey
    , WebPageProxy_WritePromisedAttachmentToPasteboard
    , WebPageProxy_toggleAutomaticDashSubstitution
    , WebPageProxy_toggleAutomaticLinkDetection
    , WebPageProxy_toggleAutomaticQuoteSubstitution
    , WebPageProxy_toggleAutomaticTextReplacement
    , WebPageProxy_toggleSmartInsertDelete
    , WebPage_AcceptsFirstMouse
    , WebPage_AccessibilitySettingsDidChange
    , WebPage_AddConsoleMessage
    , WebPage_AddMIMETypeWithCustomContentProvider
    , WebPage_AdvanceToNextMisspelling
    , WebPage_ApplicationDidBecomeActive
    , WebPage_ApplicationDidEnterBackground
    , WebPage_ApplicationDidEnterBackgroundForMedia
    , WebPage_ApplicationDidFinishSnapshottingAfterEnteringBackground
    , WebPage_ApplicationWillEnterForeground
    , WebPage_ApplicationWillEnterForegroundForMedia
    , WebPage_ApplicationWillResignActive
    , WebPage_ApplyAutocorrection
    , WebPage_AttemptSyntheticClick
    , WebPage_AttributedSubstringForCharacterRangeAsync
    , WebPage_AutofillLoginCredentials
    , WebPage_BeginPrinting
    , WebPage_BeginSelectionInDirection
    , WebPage_BlurFocusedElement
    , WebPage_BoundaryEventOccurred
    , WebPage_CancelAutoscroll
    , WebPage_CancelComposition
    , WebPage_CancelPointer
    , WebPage_CancelPotentialTap
    , WebPage_CapitalizeWord
    , WebPage_CaptureDevicesChanged
    , WebPage_CenterSelectionInVisibleArea
    , WebPage_ChangeFont
    , WebPage_ChangeFontAttributes
    , WebPage_ChangeListType
    , WebPage_ChangeSpellingToWord
    , WebPage_CharacterIndexForPointAsync
    , WebPage_ClearLoadedThirdPartyDomains
    , WebPage_ClearSelection
    , WebPage_ClearServiceWorkerEntitlementOverride
    , WebPage_ClearServiceWorkerEntitlementOverrideReply
    , WebPage_Close
    , WebPage_CollapseSelectionInFrame
    , WebPage_CommitPotentialTap
    , WebPage_CompleteTextManipulation
    , WebPage_CompleteTextManipulationReply
    , WebPage_ComputePagesForPrinting
    , WebPage_ComputePagesForPrintingAndDrawToPDF
    , WebPage_ConfirmCompositionAsync
    , WebPage_ConnectInspector
    , WebPage_ContentSizeCategoryDidChange
    , WebPage_ContextMenuForKeyEvent
    , WebPage_ContextMenuHidden
    , WebPage_ContinueWillSubmitForm
    , WebPage_CountStringMatches
    , WebPage_DataDetectorsDidChangeUI
    , WebPage_DataDetectorsDidHideUI
    , WebPage_DataDetectorsDidPresentUI
    , WebPage_DecreaseListLevel
    , WebPage_DeleteSurrounding
    , WebPage_DetectDataInAllFrames
    , WebPage_DetectDataInAllFramesReply
    , WebPage_DidAcquirePointerLock
    , WebPage_DidCancelCheckingText
    , WebPage_DidCancelForOpenPanel
    , WebPage_DidChangeSelectedIndexForActivePopupMenu
    , WebPage_DidChooseColor
    , WebPage_DidChooseFilesForOpenPanel
    , WebPage_DidChooseFilesForOpenPanelWithDisplayStringAndIcon
    , WebPage_DidCloseSuggestions
    , WebPage_DidConcludeDrop
    , WebPage_DidEndColorPicker
    , WebPage_DidEndMagnificationGesture
    , WebPage_DidEndRequestInstallMissingMediaPlugins
    , WebPage_DidFinishCheckingText
    , WebPage_DidGetLoadDecisionForIcon
    , WebPage_DidLosePointerLock
    , WebPage_DidNotAcquirePointerLock
    , WebPage_DidReceiveGeolocationPermissionDecision
    , WebPage_DidReceiveNotificationPermissionDecision
    , WebPage_DidReceivePolicyDecision
    , WebPage_DidRecognizeLongPress
    , WebPage_DidRemoveBackForwardItem
    , WebPage_DidRemoveEditCommand
    , WebPage_DidSelectDataListOption
    , WebPage_DidSelectItemFromActiveContextMenu
    , WebPage_DidStartDrag
    , WebPage_DisconnectInspector
    , WebPage_DragCancelled
    , WebPage_DragEnded
    , WebPage_DrawPagesForPrinting
    , WebPage_DrawPagesToPDF
    , WebPage_DrawRectToImage
    , WebPage_DrawToPDF
    , WebPage_DynamicViewportSizeUpdate
    , WebPage_EffectiveAppearanceDidChange
    , WebPage_EndPrinting
    , WebPage_EnqueueSecurityPolicyViolationEvent
    , WebPage_ExecuteEditCommand
    , WebPage_ExecuteEditCommandWithCallback
    , WebPage_ExecuteEditCommandWithCallbackReply
    , WebPage_ExtendSandboxForFilesFromOpenPanel
    , WebPage_ExtendSelection
    , WebPage_FailedToShowPopupMenu
    , WebPage_FindString
    , WebPage_FindStringMatches
    , WebPage_FindStringReply
    , WebPage_FirstRectForCharacterRangeAsync
    , WebPage_FocusNextFocusedElement
    , WebPage_FocusNextFocusedElementReply
    , WebPage_FocusTextInputContextAndPlaceCaret
    , WebPage_FocusTextInputContextAndPlaceCaretReply
    , WebPage_FontAtSelection
    , WebPage_ForceRepaint
    , WebPage_FrameBecameRemote
    , WebPage_FreezeLayerTreeDueToSwipeAnimation
    , WebPage_GamepadActivity
    , WebPage_GenerateSyntheticEditingCommand
    , WebPage_GetAllFrames
    , WebPage_GetAllFramesReply
    , WebPage_GetApplicationManifest
    , WebPage_GetBytecodeProfile
    , WebPage_GetCenterForZoomGesture
    , WebPage_GetContentsAsAttributedString
    , WebPage_GetContentsAsAttributedStringReply
    , WebPage_GetContentsAsMHTMLData
    , WebPage_GetContentsAsString
    , WebPage_GetDataSelectionForPasteboard
    , WebPage_GetImageForFindMatch
    , WebPage_GetMainResourceDataOfFrame
    , WebPage_GetMarkedRangeAsync
    , WebPage_GetMarkedRangeAsyncReply
    , WebPage_GetPositionInformation
    , WebPage_GetProcessDisplayName
    , WebPage_GetProcessDisplayNameReply
    , WebPage_GetRectsAtSelectionOffsetWithText
    , WebPage_GetRectsForGranularityWithSelectionOffset
    , WebPage_GetRenderTreeExternalRepresentation
    , WebPage_GetResourceDataFromFrame
    , WebPage_GetSamplingProfilerOutput
    , WebPage_GetSelectedRangeAsync
    , WebPage_GetSelectedRangeAsyncReply
    , WebPage_GetSelectionAsWebArchiveData
    , WebPage_GetSelectionContext
    , WebPage_GetSelectionOrContentsAsString
    , WebPage_GetSourceForFrame
    , WebPage_GetStringSelectionForPasteboard
    , WebPage_GetWebArchiveOfFrame
    , WebPage_GoToBackForwardItem
    , WebPage_HandleAcceptedCandidate
    , WebPage_HandleAlternativeTextUIResult
    , WebPage_HandleDoubleTapForDoubleClickAtPoint
    , WebPage_HandleMediaEvent
    , WebPage_HandleStylusSingleTapAtPoint
    , WebPage_HandleTwoFingerTapAtPoint
    , WebPage_HardwareKeyboardAvailabilityChanged
    , WebPage_HasMarkedText
    , WebPage_HasMarkedTextReply
    , WebPage_HideFindUI
    , WebPage_ImmediateActionDidCancel
    , WebPage_ImmediateActionDidComplete
    , WebPage_ImmediateActionDidUpdate
    , WebPage_IncreaseListLevel
    , WebPage_IndicateFindMatch
    , WebPage_InsertAttachment
    , WebPage_InsertDictatedTextAsync
    , WebPage_InsertDroppedImagePlaceholders
    , WebPage_InsertDroppedImagePlaceholdersReply
    , WebPage_InsertTextAsync
    , WebPage_InsertTextPlaceholder
    , WebPage_InsertTextPlaceholderReply
    , WebPage_InspectorNodeSearchEndedAtPosition
    , WebPage_InspectorNodeSearchMovedToPosition
    , WebPage_KeyEvent
    , WebPage_ListenForLayoutMilestones
    , WebPage_LoadAlternateHTML
    , WebPage_LoadData
    , WebPage_LoadDataInFrame
    , WebPage_LoadRequest
    , WebPage_LoadRequestWaitingForProcessLaunch
    , WebPage_LoadURLInFrame
    , WebPage_LoadedThirdPartyDomains
    , WebPage_LoadedThirdPartyDomainsReply
    , WebPage_LowercaseWord
    , WebPage_MouseEvent
    , WebPage_MoveSelectionAtBoundaryWithDirection
    , WebPage_MoveSelectionAtBoundaryWithDirectionReply
    , WebPage_MoveSelectionByOffset
    , WebPage_MoveSelectionByOffsetReply
    , WebPage_NavigateToPDFLinkWithSimulatedClick
    , WebPage_NotifyUserScripts
    , WebPage_PerformActionOnElement
    , WebPage_PerformDictionaryLookupAtLocation
    , WebPage_PerformDictionaryLookupOfCurrentSelection
    , WebPage_PerformDragControllerAction
    , WebPage_PerformImmediateActionHitTestAtLocation
    , WebPage_PlaybackTargetAvailabilityDidChange
    , WebPage_PlaybackTargetPickerWasDismissed
    , WebPage_PlaybackTargetSelected
    , WebPage_PostInjectedBundleMessage
    , WebPage_PotentialTapAtPosition
    , WebPage_PreferencesDidChange
    , WebPage_ReadSelectionFromPasteboard
    , WebPage_ReapplyEditCommand
    , WebPage_RegisterUIProcessAccessibilityTokens
    , WebPage_RegisterURLSchemeHandler
    , WebPage_Reload
    , WebPage_RemoveDataDetectedLinks
    , WebPage_RemoveDataDetectedLinksReply
    , WebPage_RemoveTextPlaceholder
    , WebPage_RemoveTextPlaceholderReply
    , WebPage_ReplaceDictatedText
    , WebPage_ReplaceMatches
    , WebPage_ReplaceSelectedText
    , WebPage_ReplaceSelectionWithPasteboardData
    , WebPage_RequestActiveNowPlayingSessionInfo
    , WebPage_RequestAdditionalItemsForDragSession
    , WebPage_RequestAutocorrectionContext
    , WebPage_RequestAutocorrectionData
    , WebPage_RequestAutocorrectionDataReply
    , WebPage_RequestDictationContext
    , WebPage_RequestDocumentEditingContext
    , WebPage_RequestDocumentEditingContextReply
    , WebPage_RequestDragStart
    , WebPage_RequestEvasionRectsAboveSelection
    , WebPage_RequestEvasionRectsAboveSelectionReply
    , WebPage_RequestFocusedElementInformation
    , WebPage_RequestFontAttributesAtSelectionStart
    , WebPage_RequestPositionInformation
    , WebPage_ResetPotentialTapSecurityOrigin
    , WebPage_RestoreSelectionInFocusedEditableElement
    , WebPage_RestoreSession
    , WebPage_ResumeActiveDOMObjectsAndAnimations
    , WebPage_ResumeAllMediaPlayback
    , WebPage_RunJavaScriptInFrameInScriptWorld
    , WebPage_ScalePage
    , WebPage_ScalePageInViewCoordinates
    , WebPage_ScaleView
    , WebPage_ScheduleFullEditorStateUpdate
    , WebPage_ScrollBy
    , WebPage_SelectAll
    , WebPage_SelectFindMatch
    , WebPage_SelectPositionAtBoundaryWithDirection
    , WebPage_SelectPositionAtBoundaryWithDirectionReply
    , WebPage_SelectPositionAtPoint
    , WebPage_SelectPositionAtPointReply
    , WebPage_SelectTextWithGranularityAtPoint
    , WebPage_SelectTextWithGranularityAtPointReply
    , WebPage_SelectWithGesture
    , WebPage_SelectWithTwoTouches
    , WebPage_SelectWordBackward
    , WebPage_SendCSPViolationReport
    , WebPage_SendComplexTextInputToPlugin
    , WebPage_SendMessageToTargetBackend
    , WebPage_SendMessageToWebExtension
    , WebPage_SendMessageToWebExtensionWithReply
    , WebPage_SendMessageToWebExtensionWithReplyReply
    , WebPage_SetActivityState
    , WebPage_SetAllowsMediaDocumentInlinePlayback
    , WebPage_SetAlwaysShowsHorizontalScroller
    , WebPage_SetAlwaysShowsVerticalScroller
    , WebPage_SetAutoSizingShouldExpandToViewHeight
    , WebPage_SetBackgroundColor
    , WebPage_SetBackgroundExtendsBeyondPage
    , WebPage_SetBaseWritingDirection
    , WebPage_SetCanRunBeforeUnloadConfirmPanel
    , WebPage_SetCanRunModal
    , WebPage_SetCanShowPlaceholder
    , WebPage_SetCompositionAsync
    , WebPage_SetControlledByAutomation
    , WebPage_SetCurrentHistoryItemForReattach
    , WebPage_SetCustomTextEncodingName
    , WebPage_SetDefersLoading
    , WebPage_SetDeviceOrientation
    , WebPage_SetEditable
    , WebPage_SetEnableHorizontalRubberBanding
    , WebPage_SetEnableVerticalRubberBanding
    , WebPage_SetFixedLayoutSize
    , WebPage_SetFocusedElementSelectedIndex
    , WebPage_SetFocusedElementValue
    , WebPage_SetFocusedElementValueAsNumber
    , WebPage_SetFooterBannerHeightForTesting
    , WebPage_SetForceAlwaysUserScalable
    , WebPage_SetGapBetweenPages
    , WebPage_SetHasResourceLoadClient
    , WebPage_SetHeaderBannerHeightForTesting
    , WebPage_SetIndicating
    , WebPage_SetInitialFocus
    , WebPage_SetInitialFocusReply
    , WebPage_SetIsShowingInputViewForFocusedElement
    , WebPage_SetIsSuspended
    , WebPage_SetLayerHostingMode
    , WebPage_SetMainFrameIsScrollable
    , WebPage_SetMaximumUnobscuredSize
    , WebPage_SetMayStartMediaWhenInWindow
    , WebPage_SetMediaVolume
    , WebPage_SetMinimumSizeForAutoLayout
    , WebPage_SetMuted
    , WebPage_SetNeedsDOMWindowResizeEvent
    , WebPage_SetNeedsFontAttributes
    , WebPage_SetOverriddenMediaType
    , WebPage_SetOverrideViewportArguments
    , WebPage_SetPageAndTextZoomFactors
    , WebPage_SetPageLength
    , WebPage_SetPageZoomFactor
    , WebPage_SetPaginationBehavesLikeColumns
    , WebPage_SetPaginationLineGridEnabled
    , WebPage_SetPaginationMode
    , WebPage_SetScreenIsBeingCaptured
    , WebPage_SetScrollPinningBehavior
    , WebPage_SetScrollbarOverlayStyle
    , WebPage_SetShouldDispatchFakeMouseMoveEvents
    , WebPage_SetShouldFireEvents
    , WebPage_SetShouldPlayToPlaybackTarget
    , WebPage_SetShouldRevealCurrentSelectionAfterInsertion
    , WebPage_SetShouldScaleViewToFitDocument
    , WebPage_SetSizeToContentAutoSizeMaximumSize
    , WebPage_SetSmartInsertDeleteEnabled
    , WebPage_SetSuppressScrollbarAnimations
    , WebPage_SetTextAsync
    , WebPage_SetTextForActivePopupMenu
    , WebPage_SetTextZoomFactor
    , WebPage_SetTopContentInset
    , WebPage_SetTopContentInsetFenced
    , WebPage_SetUnderlayColor
    , WebPage_SetUseFixedLayout
    , WebPage_SetUseIconLoadingClient
    , WebPage_SetUseSystemAppearance
    , WebPage_SetUserAgent
    , WebPage_SetUserInterfaceLayoutDirection
    , WebPage_SetViewportConfigurationViewLayoutSize
    , WebPage_SetViewportSizeForCSSViewportUnits
    , WebPage_SetVolumeOfMediaElement
    , WebPage_ShouldDelayWindowOrderingEvent
    , WebPage_SimulateDeviceOrientationChange
    , WebPage_SpeakingErrorOccurred
    , WebPage_StartAutoscrollAtPosition
    , WebPage_StartInteractionWithElementContextOrPosition
    , WebPage_StartTextManipulations
    , WebPage_StartTextManipulationsReply
    , WebPage_StopAllMediaPlayback
    , WebPage_StopInteraction
    , WebPage_StopLoading
    , WebPage_StopLoadingFrame
    , WebPage_StopMediaCapture
    , WebPage_StoreSelectionForAccessibility
    , WebPage_SuspendActiveDOMObjectsAndAnimations
    , WebPage_SuspendAllMediaPlayback
    , WebPage_SyncApplyAutocorrection
    , WebPage_SystemPreviewActionTriggered
    , WebPage_TakeSnapshot
    , WebPage_TapHighlightAtPosition
    , WebPage_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply
    , WebPage_TextInputContextsInRect
    , WebPage_TextInputContextsInRectReply
    , WebPage_ThemeDidChange
    , WebPage_TouchEvent
    , WebPage_TouchEventSync
    , WebPage_TouchWithIdentifierWasRemoved
    , WebPage_TryClose
    , WebPage_TryCloseReply
    , WebPage_TryRestoreScrollPosition
    , WebPage_URLSchemeTaskDidComplete
    , WebPage_URLSchemeTaskDidPerformRedirection
    , WebPage_URLSchemeTaskDidReceiveData
    , WebPage_URLSchemeTaskDidReceiveResponse
    , WebPage_UnapplyEditCommand
    , WebPage_UnfreezeLayerTreeDueToSwipeAnimation
    , WebPage_UpdateAttachmentAttributes
    , WebPage_UpdateAttachmentIcon
    , WebPage_UpdateBackForwardListForReattach
    , WebPage_UpdateCORSDisablingPatterns
    , WebPage_UpdateCurrentModifierState
    , WebPage_UpdateSelectionWithDelta
    , WebPage_UpdateSelectionWithDeltaReply
    , WebPage_UpdateSelectionWithExtentPoint
    , WebPage_UpdateSelectionWithExtentPointAndBoundary
    , WebPage_UpdateSelectionWithTouches
    , WebPage_UpdateWebsitePolicies
    , WebPage_UppercaseWord
    , WebPage_UserMediaAccessWasDenied
    , WebPage_UserMediaAccessWasGranted
    , WebPage_UserMediaAccessWasGrantedReply
    , WebPage_ValidateCommand
    , WebPage_ViewWillEndLiveResize
    , WebPage_ViewWillStartLiveResize
    , WebPage_VoicesDidChange
    , WebPage_WasLoadedWithDataTransferFromPrevalentResource
    , WebPage_WillStartUserTriggeredZooming
    , WebPage_WindowAndViewFramesChanged
    , WebPage_WindowScreenDidChange
    , WebPage_clearWheelEventTestMonitor
    , WebPasteboardProxy_AddPasteboardTypes
    , WebPasteboardProxy_AllPasteboardItemInfo
    , WebPasteboardProxy_ClearClipboard
    , WebPasteboardProxy_ContainsStringSafeForDOMToReadForType
    , WebPasteboardProxy_ContainsURLStringSuitableForLoading
    , WebPasteboardProxy_GetNumberOfFiles
    , WebPasteboardProxy_GetPasteboardBufferForType
    , WebPasteboardProxy_GetPasteboardChangeCount
    , WebPasteboardProxy_GetPasteboardColor
    , WebPasteboardProxy_GetPasteboardItemsCount
    , WebPasteboardProxy_GetPasteboardPathnamesForType
    , WebPasteboardProxy_GetPasteboardStringForType
    , WebPasteboardProxy_GetPasteboardStringsForType
    , WebPasteboardProxy_GetPasteboardTypes
    , WebPasteboardProxy_GetPasteboardURL
    , WebPasteboardProxy_GetTypes
    , WebPasteboardProxy_InformationForItemAtIndex
    , WebPasteboardProxy_ReadBuffer
    , WebPasteboardProxy_ReadBufferFromPasteboard
    , WebPasteboardProxy_ReadFilePaths
    , WebPasteboardProxy_ReadStringFromPasteboard
    , WebPasteboardProxy_ReadText
    , WebPasteboardProxy_ReadURLFromPasteboard
    , WebPasteboardProxy_SetPasteboardBufferForType
    , WebPasteboardProxy_SetPasteboardColor
    , WebPasteboardProxy_SetPasteboardStringForType
    , WebPasteboardProxy_SetPasteboardTypes
    , WebPasteboardProxy_SetPasteboardURL
    , WebPasteboardProxy_TypesSafeForDOMToReadAndWrite
    , WebPasteboardProxy_URLStringSuitableForLoading
    , WebPasteboardProxy_UpdateSupportedTypeIdentifiers
    , WebPasteboardProxy_WriteCustomData
    , WebPasteboardProxy_WriteImageToPasteboard
    , WebPasteboardProxy_WriteStringToPasteboard
    , WebPasteboardProxy_WriteToClipboard
    , WebPasteboardProxy_WriteURLToPasteboard
    , WebPasteboardProxy_WriteWebContentToPasteboard
    , WebProcessConnection_CreatePlugin
    , WebProcessConnection_CreatePluginAsynchronously
    , WebProcessConnection_DestroyPlugin
    , WebProcessPool_HandleMessage
    , WebProcessPool_HandleSynchronousMessage
    , WebProcessPool_ReportWebContentCPUTime
    , WebProcessPool_StartedUsingGamepads
    , WebProcessPool_StoppedUsingGamepads
    , WebProcessProxy_AddPlugInAutoStartOriginHash
    , WebProcessProxy_CacheMediaMIMETypes
    , WebProcessProxy_DidCollectPrewarmInformation
    , WebProcessProxy_DidCreateSleepDisabler
    , WebProcessProxy_DidDestroyFrame
    , WebProcessProxy_DidDestroySleepDisabler
    , WebProcessProxy_DidDestroyUserGestureToken
    , WebProcessProxy_DidExceedActiveMemoryLimit
    , WebProcessProxy_DidExceedCPULimit
    , WebProcessProxy_DidExceedInactiveMemoryLimit
    , WebProcessProxy_DidExceedInactiveMemoryLimitWhileActive
    , WebProcessProxy_DidReceiveBackgroundResponsivenessPing
    , WebProcessProxy_DidReceiveMainThreadPing
    , WebProcessProxy_DisableSuddenTermination
    , WebProcessProxy_EnableSuddenTermination
    , WebProcessProxy_GetGPUProcessConnection
    , WebProcessProxy_GetNetworkProcessConnection
    , WebProcessProxy_GetPluginProcessConnection
    , WebProcessProxy_GetPlugins
    , WebProcessProxy_MemoryPressureStatusChanged
    , WebProcessProxy_PlugInDidReceiveUserInteraction
    , WebProcessProxy_ReleaseHighPerformanceGPU
    , WebProcessProxy_RequestHighPerformanceGPU
    , WebProcessProxy_SendMessageToWebContext
    , WebProcessProxy_SendMessageToWebContextWithReply
    , WebProcessProxy_SendMessageToWebContextWithReplyReply
    , WebProcessProxy_SetIsHoldingLockedFiles
    , WebProcessProxy_ShouldTerminate
    , WebProcessProxy_StartDisplayLink
    , WebProcessProxy_StopDisplayLink
    , WebProcessProxy_StopResponsivenessTimer
    , WebProcessProxy_UpdateBackForwardItem
    , WebProcess_AddMockMediaDevice
    , WebProcess_BackgroundResponsivenessPing
    , WebProcess_BacklightLevelDidChange
    , WebProcess_ClearCachedPage
    , WebProcess_ClearCachedPageReply
    , WebProcess_ClearCurrentModifierStateForTesting
    , WebProcess_ClearMockMediaDevices
    , WebProcess_ClearPluginClientPolicies
    , WebProcess_ClearResourceLoadStatistics
    , WebProcess_CreateWebPage
    , WebProcess_DeleteWebsiteData
    , WebProcess_DeleteWebsiteDataForOrigins
    , WebProcess_DeleteWebsiteDataForOriginsReply
    , WebProcess_DeleteWebsiteDataReply
    , WebProcess_DestroyAutomationSessionProxy
    , WebProcess_DidAddPlugInAutoStartOriginHash
    , WebProcess_DisplayConfigurationChanged
    , WebProcess_EnableRemoteWebInspector
    , WebProcess_EnsureAutomationSessionProxy
    , WebProcess_EstablishWorkerContextConnectionToNetworkProcess
    , WebProcess_EstablishWorkerContextConnectionToNetworkProcessReply
    , WebProcess_FetchWebsiteData
    , WebProcess_FetchWebsiteDataReply
    , WebProcess_FullKeyboardAccessModeChanged
    , WebProcess_GamepadConnected
    , WebProcess_GamepadDisconnected
    , WebProcess_GarbageCollectJavaScriptObjects
    , WebProcess_GetActivePagesOriginsForTesting
    , WebProcess_GetActivePagesOriginsForTestingReply
    , WebProcess_GrantAccessToAssetServices
    , WebProcess_GrantUserMediaDeviceSandboxExtensions
    , WebProcess_HandleInjectedBundleMessage
    , WebProcess_InitializeWebProcess
    , WebProcess_IsJITEnabled
    , WebProcess_IsJITEnabledReply
    , WebProcess_MainThreadPing
    , WebProcess_MarkIsNoLongerPrewarmed
    , WebProcess_NotifyPreferencesChanged
    , WebProcess_PrepareToSuspend
    , WebProcess_PrepareToSuspendReply
    , WebProcess_PrewarmGlobally
    , WebProcess_PrewarmWithDomainInformation
    , WebProcess_ProcessDidResume
    , WebProcess_RefreshPlugins
    , WebProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy
    , WebProcess_RegisterURLSchemeAsCORSEnabled
    , WebProcess_RegisterURLSchemeAsCachePartitioned
    , WebProcess_RegisterURLSchemeAsCanDisplayOnlyIfCanRequest
    , WebProcess_RegisterURLSchemeAsDisplayIsolated
    , WebProcess_RegisterURLSchemeAsEmptyDocument
    , WebProcess_RegisterURLSchemeAsLocal
    , WebProcess_RegisterURLSchemeAsNoAccess
    , WebProcess_RegisterURLSchemeAsSecure
    , WebProcess_RemoveMockMediaDevice
    , WebProcess_ResetMockMediaDevices
    , WebProcess_ResetPlugInAutoStartOriginHashes
    , WebProcess_ResetPluginLoadClientPolicies
    , WebProcess_RevokeAccessToAssetServices
    , WebProcess_RevokeUserMediaDeviceSandboxExtensions
    , WebProcess_ScrollerStylePreferenceChanged
    , WebProcess_SeedResourceLoadStatisticsForTesting
    , WebProcess_SeedResourceLoadStatisticsForTestingReply
    , WebProcess_SendMessageToWebExtension
    , WebProcess_SetAlwaysUsesComplexTextCodePath
    , WebProcess_SetBackForwardCacheCapacity
    , WebProcess_SetCacheModel
    , WebProcess_SetDefaultRequestTimeoutInterval
    , WebProcess_SetDomainRelaxationForbiddenForURLScheme
    , WebProcess_SetDomainsWithUserInteraction
    , WebProcess_SetEnabledServices
    , WebProcess_SetEnhancedAccessibility
    , WebProcess_SetHasSuspendedPageProxy
    , WebProcess_SetHiddenPageDOMTimerThrottlingIncreaseLimit
    , WebProcess_SetInitialGamepads
    , WebProcess_SetInjectedBundleParameter
    , WebProcess_SetInjectedBundleParameters
    , WebProcess_SetIsInProcessCache
    , WebProcess_SetJavaScriptGarbageCollectorTimerEnabled
    , WebProcess_SetMediaMIMETypes
    , WebProcess_SetMemoryCacheDisabled
    , WebProcess_SetPluginLoadClientPolicy
    , WebProcess_SetQOS
    , WebProcess_SetResourceLoadStatisticsEnabled
    , WebProcess_SetScreenProperties
    , WebProcess_SetShouldUseFontSmoothing
    , WebProcess_SetTextCheckerState
    , WebProcess_SetThirdPartyCookieBlockingMode
    , WebProcess_SetThirdPartyCookieBlockingModeReply
    , WebProcess_SetUseSystemAppearanceForScrollbars
    , WebProcess_SetWebsiteDataStoreParameters
    , WebProcess_StartMemorySampler
    , WebProcess_StopMemorySampler
    , WebProcess_UnblockPreferenceService
    , WebProcess_UnblockServicesRequiredByAccessibility
    , WebProcess_UserPreferredLanguagesChanged
    , WebRTCMonitor_NetworksChanged
    , WebRTCResolver_ResolvedAddressError
    , WebRTCResolver_SetResolvedAddress
    , WebResourceLoader_DidBlockAuthenticationChallenge
    , WebResourceLoader_DidFailResourceLoad
    , WebResourceLoader_DidFailServiceWorkerLoad
    , WebResourceLoader_DidFinishResourceLoad
    , WebResourceLoader_DidReceiveData
    , WebResourceLoader_DidReceiveResource
    , WebResourceLoader_DidReceiveResponse
    , WebResourceLoader_DidReceiveSharedBuffer
    , WebResourceLoader_DidSendData
    , WebResourceLoader_ServiceWorkerDidNotHandle
    , WebResourceLoader_StopLoadingAfterXFrameOptionsOrContentSecurityPolicyDenied
    , WebResourceLoader_WillSendRequest
    , WebSWClientConnection_DidGetRegistrations
    , WebSWClientConnection_DidMatchRegistration
    , WebSWClientConnection_FireUpdateFoundEvent
    , WebSWClientConnection_JobRejectedInServer
    , WebSWClientConnection_NotifyClientsOfControllerChange
    , WebSWClientConnection_PostMessageToServiceWorkerClient
    , WebSWClientConnection_RegistrationJobResolvedInServer
    , WebSWClientConnection_RegistrationReady
    , WebSWClientConnection_SetDocumentIsControlled
    , WebSWClientConnection_SetDocumentIsControlledReply
    , WebSWClientConnection_SetRegistrationLastUpdateTime
    , WebSWClientConnection_SetRegistrationUpdateViaCache
    , WebSWClientConnection_SetSWOriginTableIsImported
    , WebSWClientConnection_SetSWOriginTableSharedMemory
    , WebSWClientConnection_StartScriptFetchForServer
    , WebSWClientConnection_UpdateRegistrationState
    , WebSWClientConnection_UpdateWorkerState
    , WebSWContextManagerConnection_CancelFetch
    , WebSWContextManagerConnection_Close
    , WebSWContextManagerConnection_ContinueDidReceiveFetchResponse
    , WebSWContextManagerConnection_FindClientByIdentifierCompleted
    , WebSWContextManagerConnection_FireActivateEvent
    , WebSWContextManagerConnection_FireInstallEvent
    , WebSWContextManagerConnection_InstallServiceWorker
    , WebSWContextManagerConnection_MatchAllCompleted
    , WebSWContextManagerConnection_PostMessageToServiceWorker
    , WebSWContextManagerConnection_SetThrottleState
    , WebSWContextManagerConnection_SetUserAgent
    , WebSWContextManagerConnection_StartFetch
    , WebSWContextManagerConnection_TerminateWorker
    , WebSWContextManagerConnection_UpdatePreferencesStore
    , WebSWServerConnection_AddServiceWorkerRegistrationInServer
    , WebSWServerConnection_DidResolveRegistrationPromise
    , WebSWServerConnection_FinishFetchingScriptInServer
    , WebSWServerConnection_GetRegistrations
    , WebSWServerConnection_MatchRegistration
    , WebSWServerConnection_PostMessageToServiceWorker
    , WebSWServerConnection_RegisterServiceWorkerClient
    , WebSWServerConnection_RemoveServiceWorkerRegistrationInServer
    , WebSWServerConnection_ScheduleJobInServer
    , WebSWServerConnection_ScheduleUnregisterJobInServer
    , WebSWServerConnection_ScheduleUnregisterJobInServerReply
    , WebSWServerConnection_SetThrottleState
    , WebSWServerConnection_StoreRegistrationsOnDisk
    , WebSWServerConnection_StoreRegistrationsOnDiskReply
    , WebSWServerConnection_TerminateWorkerFromClient
    , WebSWServerConnection_TerminateWorkerFromClientReply
    , WebSWServerConnection_UnregisterServiceWorkerClient
    , WebSWServerConnection_WhenRegistrationReady
    , WebSWServerConnection_WhenServiceWorkerIsTerminatedForTesting
    , WebSWServerConnection_WhenServiceWorkerIsTerminatedForTestingReply
    , WebSWServerToContextConnection_Claim
    , WebSWServerToContextConnection_ClaimReply
    , WebSWServerToContextConnection_DidFailHeartBeatCheck
    , WebSWServerToContextConnection_DidFinishActivation
    , WebSWServerToContextConnection_DidFinishInstall
    , WebSWServerToContextConnection_FindClientByIdentifier
    , WebSWServerToContextConnection_MatchAll
    , WebSWServerToContextConnection_PostMessageToServiceWorkerClient
    , WebSWServerToContextConnection_ScriptContextFailedToStart
    , WebSWServerToContextConnection_ScriptContextStarted
    , WebSWServerToContextConnection_SetScriptResource
    , WebSWServerToContextConnection_SetServiceWorkerHasPendingEvents
    , WebSWServerToContextConnection_SkipWaiting
    , WebSWServerToContextConnection_SkipWaitingReply
    , WebSWServerToContextConnection_WorkerTerminated
    , WebSocketChannel_DidClose
    , WebSocketChannel_DidConnect
    , WebSocketChannel_DidReceiveBinaryData
    , WebSocketChannel_DidReceiveHandshakeResponse
    , WebSocketChannel_DidReceiveMessageError
    , WebSocketChannel_DidReceiveText
    , WebSocketChannel_DidSendHandshakeRequest
    , WebSocketStream_DidCloseSocketStream
    , WebSocketStream_DidFailSocketStream
    , WebSocketStream_DidFailToReceiveSocketStreamData
    , WebSocketStream_DidOpenSocketStream
    , WebSocketStream_DidReceiveSocketStreamData
    , WebSocketStream_DidSendData
    , WebSocketStream_DidSendHandshake
    , WebSocketStream_DidUpdateBufferedAmount
    , WebUserContentControllerProxy_DidPostMessage
    , WebUserContentControllerProxy_DidPostMessageReply
    , WebUserContentController_AddContentRuleLists
    , WebUserContentController_AddContentWorlds
    , WebUserContentController_AddUserScriptMessageHandlers
    , WebUserContentController_AddUserScripts
    , WebUserContentController_AddUserStyleSheets
    , WebUserContentController_RemoveAllContentRuleLists
    , WebUserContentController_RemoveAllUserScriptMessageHandlers
    , WebUserContentController_RemoveAllUserScriptMessageHandlersForWorlds
    , WebUserContentController_RemoveAllUserScripts
    , WebUserContentController_RemoveAllUserStyleSheets
    , WebUserContentController_RemoveContentRuleList
    , WebUserContentController_RemoveContentWorlds
    , WebUserContentController_RemoveUserScript
    , WebUserContentController_RemoveUserScriptMessageHandler
    , WebUserContentController_RemoveUserStyleSheet
    , WrappedAsyncMessageForTesting
    , SyncMessageReply
    , InitializeConnection
    , LegacySessionState
    , Last = LegacySessionState
};

ReceiverName receiverName(MessageName);
const char* description(MessageName);
bool isValidMessageName(MessageName);

} // namespace IPC

namespace WTF {

template<>
class HasCustomIsValidEnum<IPC::MessageName> : public std::true_type { };
template<typename E, typename T, std::enable_if_t<std::is_same_v<E, IPC::MessageName>>* = nullptr>
bool isValidEnum(T messageName)
{
    static_assert(sizeof(T) == sizeof(E), "isValidEnum<IPC::MessageName> should only be called with 16-bit types");
    static_assert(std::is_unsigned<T>::value, "isValidEnum<IPC::MessageName> should only be called with unsigned types");
    if (messageName > static_cast<std::underlying_type<IPC::MessageName>::type>(IPC::MessageName::Last))
        return false;
    return IPC::isValidMessageName(static_cast<E>(messageName));
};

} // namespace WTF
